Hawaii Appellate Court Opinions and Orders
Description: The official website of the Hawaii State Judiciary. Provides access to case records, forms, contact information and Appellate Court opinions
Keywords: hawaii judiciary, hawaii court, hawaii state judiciary, hawaii state court, hawaii court records, hawaii case records, hawaii court forms

Skip to main content | Skip to text menu

- General Information
  - Contact Information
  - Job Opportunities
  - Jury Service
  - Judiciary Overview
  - Court Administration
  - Business with Judiciary
- News & Reports
  - Press Releases
  - Legislative Update
  - Reports
  - In the Media
  - Oral Arguments
  - Media Guidelines
  - Speeches
- Self-Help
  - Court Forms
  - Traffic Cases
  - Self-Help Centers
  - Protective Orders
  - Mortgage Foreclosure
  - Small Claims
  - Regular Claims
  - Divorce
  - Landlord-Tenant Claims
  - Tips on Going to Court
- Services
  - ADA
  - Court Interpreting
  - Law Library
  - Mediation/ADR
  - Children's Justice Centers
  - Victim Services
  - Volunteer Settlement Master Process
  - Vehicle Tracker
- Courts
  - Supreme Court
  - Intermediate Court of Appeals
  - Circuit Court
  - District Court
  - Family Court
  - Land and Tax Appeal Courts
  - Administrative Adjudication
  - Commission on Judicial Conduct
  - Judicial Performance Reviews
  - Judicial Selection Commission
- Legal References
  - Search Court Records
  - Proposed Rules Changes
  - Supreme Court Various Orders
  - Opinions
  - Court Rules
  - Internet Resources
- Community Outreach
  - Civics Education
  - Volunteer Opportunities
  - Judiciary History Center
  - Divorce Law Seminar
  - Court Tours
  - Lunch 'N' Learn the Law
- Special Projects & Events
  - HOPE Probation
  - Girls Court

## I want to...

- Learn about the Courts
- Visit the Law Library
- See the Oral Argument Schedule
- Listen to an Oral Argument
- Read the Rules of Court
- Read Recent Appellate Opinions
- Request an ADA Accommodation
- Give Feedback

## Searches

- eCourt Kokua The Hawaii Judiciary is not affiliated with Sustain Technologies, Inc. or with eCourt®, which is a registered trademark of Sustain Technologies, Inc.
- Ho`ohiki For access to criminal and civil case information filed in the Circuit and Family courts and certain civil cases of the District Courts.
- Jobs Search for jobs at the Judiciary
- Efiling Case information.

## Status Updates

- Twitter Stream
- Facebook Fan Page
- YouTube Channel

#
Hawaii Appellate Court Opinions and Orders 2013

For 2009 and older, Case Number link will display content as an html page. PDF link will display a scanned image with file date stamp and judicial signatures. Beginning in 2010, Case Number link will display a scanned image with file date stamp and judicial signatures. ADA link will display an accessible file compatible with online reader devices.

Date | Ct. | Case Number | Case Name | Appealed From | Reporter Citation
--- | --- | --- | --- | --- | ---
05/23/2013 | S.Ct | SCWC-11-0000586 | State v. Ungounga (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 02/15/2013 [ada], 129 Haw. 106. Application for Writ of Certiorari, filed 04/12/2013. | Circuit Court, 1st Circuit |
05/23/2013 | ICA | CAAP-12-0000480 | State v. Faleta (mem.op., affirmed). | Family Court, 1st Circuit (Sexual Assault) |
05/22/2013 | S.Ct | SCWC-11-0000064 | State v. DeLeon (Order Accepting Application for Writ of Certiorari). ICA s.d.o., filed 01/18/2013 [ada], 129 Haw. 29. Application for Writ of Certiorari, filed 04/15/2013. | Circuit Court, 1st Circuit |
05/22/2013 | ICA | CAAP-12-0000095 [ADA] | Alkire-Clemen v. Castle Medical Center (s.d.o., affirmed). | Land and Industrial Relations Appeal Board (Workers' Compenation) |
05/22/2013 | ICA | CAAP-12-0000535 | Mikelson v. United Services Automobile Association (Order Denyting Motion for Partial Reconsideration of Memorandum Opinion). ICA mem.op., filed 05/06/2013 [ada]. Defendant-Appellant United Services Automobile Association's Motion for Partial Reconsideration of Memorandum Opinon, filed 05/15/2013. | Circuit Court, 1st Circuit |
05/22/2013 | S.Ct | SCWC-10-0000188 | County of Hawaii v. UniDev, LLC. | Circuit Court, 3rd Circuit |
05/22/2013 | S.Ct | SCWC-10-0000188 | County of Hawaii v. UNIDEV, LLC. ICA Opinion, filed 08/31/2012 [ada], 128 Haw. 378. Consolidated with No. CAAP-11-0000019. Application for Writ of Certiorari, filed 12/17/2012. S.Ct. Order Accepting Application for Writ of Certiorari, filed 01/28/2013 [ada]. | Circuit Court, 3rd Circuit |
05/21/2013 | ICA | CAAP-11-0000705 [ADA] | State v. Dietrich (Order of Correction). ICA mem.op., filed 05/17/2013 [ada]. | Circuit Court, 1st Circuit |
05/21/2013 | ICA | CAAP-11-0000667 [ADA] | State v. Walton (mem.op., affirmed). | Circuit Court, 1st Circuit (Criminal) |
05/21/2013 | S.Ct | SCWC-29553 [ADA] | Nakajima v. Nakajima (Order Accepting Application for Writ of Certiorari). ICA Order Dismissing Appeal, filed 02/22/2013 [ada]. Dissenting Opinion by J. Nakamura [ada]. Plaintiff/Cross-Defendant-Appellant's Motion for Reconsideration of the Court's Order Dismissing Appeal, filed 03/04/2013. ICA Order Denying "Plaintiff/Cross-Defendant-Appellant's Motion for Reconsideration of the Court's Order Dismissing Appeal filed on February 22, 2013, filed 03/08/2013 [ada]. C.J. Nakamura Dissenting. Application for Writ of Certiorari, filed 04/09/2013. | Family Court, 2nd Circuit |
05/21/2013 | S.Ct | SCWC-11-0000451 [ADA] | State v. Pali. Concurring and Dissenting Opinion by Recktenwald, C.J., in which Nakayama, J., Joins, [ada]. ICA s.d.o., filed 06/29/2012 [ada]. Application for Writ of Certiorari, filed 09/24/2012. S.Ct. Order Accepting Application for Writ of Certiorari, filed 11/07/2012 [ada]. | Circuit Court, 2nd Circuit (Criminal) |
05/21/2013 | S.Ct | SCAD-12-0001028 [ADA] | Office of Disciplinary Counsel v. Hayashi (Order of Reinstatement). S.Ct. Order, filed 03/20/2013 [ada]. | Original Proceeding |
05/21/2013 | ICA | CAAP-12-0000315 [ADA] | Krog v. Koahou (Order of Correction). ICA s.d.o., filed 05/17/2013 [ada]. | Circuit Court, 1st Circuit |
05/21/2013 | ICA | CAAP-13-0000417 [ADA] | In re Rightstar Related Cases (Order Approving Stipulation for Dismissal of Appeal Without Prejudice). | Circuit Court, 1st Circuit |
05/21/2013 | ICA | CAAP-12-0001023 [ADA] | McGrath Properties, I, LLC v. Association of Apartment Owners of Lihue Townhouse (Order Granting the May 7, 2013 Motion to Dismiss Appeal). ICA Order (1) Granting Defendants-Appellees' April 05, 2013 Motion to Dismiss Appeal by Plaintiff-Appellant McGrath Properties I, LLC, and (2) Granting Defendants-Appellees' April 16, 2013 Motion to Dismiss Appeal by Plaintiff-Appellant Suzanne Kitamura, as Custodian for DAF, filed 05/03/2013 [ada]. | Circuit Court, 5th Circuit |
05/21/2013 | ICA | CAAP-13-0000077 [ADA] | Norstrom v. Norstrom (Order Approving Stipulation to Dismiss Notice of Appeal Filed on February 7, 2013 with Prejudice). | Family Court, 1st Circuit |
05/21/2013 | ICA | CAAP-12-0000731 [ADA] | In re Trust Created Under the Will of Samuel M. Damon, Deceased (Order Dismissing the Cross-Appeal of Alexandria Murdouch Haig). | Circuit Court, 1st Circuit |
05/21/2013 | ICA | SCWC-12-0000099 | County of Hawaii v. H. Kimura Store, Inc. (Order Dismissing Application for Writ of Certiorari). ICA s.d.o., filed 04/22/2013 [ada]. Application for Writ of Certiorari, filed 05/07/2013. | Circuit Court, 3rd Circuit |
05/20/2013 | ICA | 30043 [ADA] | Waikoloa Development Co. v. Waikoloa Heights Land Investors, L.P. (mem.op., affirmed). | Circuit Court, 3rd Circuit (Civil) |
05/20/2013 | ICA | CAAP-11-0001012 [ADA] | State v. Harris (mem.op., affirmed). | Circuit Court, 3rd Circuit (Criminal) |
05/20/2013 | S.Ct | SCPW-13-0000402 [ADA] | Tierney v. Matsuoka (Order Denying Motion for Reconsideration). Petition for Writ of Mandamus, filed 04/11/2013. S.Ct. Order Denying Petition for Writ of Mandamus, filed 04/24/2013 [ada]. Motion for Reconsideration, filed 05/08/2013. | Original Proceeding |
05/20/2013 | S.Ct | SCPW-13-0000199 [ADA] | Tierney v. Sakai (Order Denying Motion for Reconsideration). Petition for Writ of Mandamus, filed 03/18/2013. S.Ct. Order Denying Petition for Writ of Mandamus, filed 04/24/2013 [ada]. Motion for Reconsideration, filed 05/08/2013. | Original Proceeding |
05/20/2013 | S.Ct | SCPR-13-0000574 [ADA] | In re Rolnick (Order Granting Petition to Resign and Surrender License). | Original Proceeding |
05/20/2013 | S.Ct | SCAD-13-0000136 [ADA] | Office of Disciplinary Counsel v. Manuia (Order of Suspension). | Original Proceeding |
05/20/2013 | S.Ct | SCPW-13-0000095 [ADA] | Tierney v. State (Order Denying Motion for Reconsideration). S.Ct. Order Denying Petition for Writ of Mandamus, filed 02/21/2013 [ada]. Motion for Reconsideration, filed 03/04/2013. S.Ct. Order Denying Motion for Reconsideration, filed 03/13/2013 [ada]. Motion for Reconsideration, filed 05/08/2013. | Original Proceeding |
05/20/2013 | S.Ct | SCPW-13-0000489 | Unciano v. Chang (Order Denying Without Prejudice Petition for Writ of Mandamus and/or Prohibition). | Land Court |
05/17/2013 | ICA | CAAP-12-0000125 [ADA] | State v. Hongel (s.d.o., affirmed). | Circuit Court, 1st Circuit (Criminal) |
05/17/2013 | ICA | CAAP-11-0000709 [ADA] | State v. Vaughan (s.d.o., affirmed). | Circuit Court, 3rd Circuit (Criminal) |
05/17/2013 | ICA | CAAP-12-0001084 [ADA] | Nakkim v. Aue (Order Dismissing Appeal Pursuant to HRAP Rule 30). | District Court, 3rd Circuit |
05/17/2013 | ICA | CAAP-13-0000076 [ADA] | In re Trust of Avery (Order Granting May 1, 2013 Motion to Dismiss Appeal for Lack of Jurisdiction). | Circuit Court, 3rd Circuit |
05/17/2013 | ICA | 30383 [ADA] | Memminger v. The Summit at Kaneohe Bay Association (s.d.o., affirmed). | Circuit Court, 1st Circuit (Civil) |
05/17/2013 | ICA | CAAP-11-0000705 [ADA] | State v. Dietrich (mem.op., affirmed). | Circuit Court, 1st Circuit (Criminal) |
05/17/2013 | ICA | CAAP-12-0000315 [ADA] | Krog v. Koahou (s.d.o., affirmed). ICA Order of Correction, filed 05/21/2013 [ada]. | Circuit Court, 1st Circuit (Civil) |
05/17/2013 | ICA | 29736 [ADA] | Yi v. Sullivan (s.d.o., affirmed). | Circuit Court, 1st Circuit (Civil) |
05/17/2013 | ICA | 30085 [ADA] | Flowers v. United Services Automobile Association (s.d.o., affirmed). | Circuit Court, 1st Circuit (Civil) |
05/17/2013 | ICA | CAAP-11-0000644 [ADA] | State v. Hern (Order of Correction). ICA Opinion, filed 03/27/2013 [ada]. Consolidated with CAAP-12-0000528. | District Court, 1st Circuit, Honolulu Division |
05/17/2013 | S.Ct | SCAP-11-0000611 [ADA] | Kaleikini v. Yoshioka (Order Denying Motion for Reconsideration). S.Ct. Opinion, filed 08/24/2012 [ada], 128 Haw. 53. Motion for Reconsideration, filed 09/04/2012. S.Ct. Order Denying Motion for Reconsideration, filed 09/27/2012 [ada], 128 Haw. 199. S.Ct. Opinion, filed 05/02/2013 [ada]. Motion for Reconsideration, filed 05/10/2013. | Circuit Court, 1st Circuit |
05/16/2013 | ICA | CAAP-12-0000511 [ADA] | Federal National Mortgage Association v. Corpuz (s.d.o., affirmed). | District Court, 1st Circuit, Honolulu Division (Civil) |
05/16/2013 | ICA | CAAP-12-0000433 [ADA] | The Bank of New York Mellon v. Velez (s.d.o., affirmed). | District Court, 3rd Circuit, South Kohala Division (Civil) |
05/16/2013 | ICA | CAAP-12-0000720 [ADA] | Griffin v. Davenport (s.d.o., affirmed). | Circuit Court, 1st Circuit (Domestic Abuse) |
05/16/2013 | ICA | CAAP-11-0000638 [ADA] | State v. Mezurashi (s.d.o., dismissed). | Circuit Court, 1st Circuit (Criminal) |
05/16/2013 | ICA | CAAP-12-0000013 [ADA] | State v. Washington (s.d.o., affirmed). | Circuit Court, 1st Circuit (Criminal) |
05/16/2013 | ICA | CAAP-12-0000380 [ADA] | State v. Slavick (s.d.o., affirmed). | Circuit Court, 1st Circuit (Criminal) |
05/16/2013 | ICA | CAAP-13-0000003 [ADA] | Debenham Family Ltd. Partnership v. Zoning Board of Appeals of the City and County of Honolulu (Order Dismissing Appeal for Lack of Appellate Jurisdiction). | Circuit Court, 1st Circuit (Civil) |
05/16/2013 | ICA | CAAP-13-0000102 [ADA] | Federal Home Loan Mortgage Corporation v. Watts (Order). | District Court, 3rd Circuit |
05/16/2013 | ICA | CAAP-11-0000811 [ADA] | Griffith v. Seven-Eleven Hawaii, Inc. (Order Approving Plaintiff-Appellant's April 30, 2013 Stipulation Dismissing Appeal). | Circuit Court, 1st Circuit (Civil) |
05/16/2013 | ICA | CAAP-12-0001024 [ADA] | Lambert v. Teisina (Order Dismissing Appeal for Lack of Appellate Jurisdiction). | Circuit Court, 1st Circuit (Civil) |
05/16/2013 | ICA | CAAP-13-0000385 [ADA] | Mizukami v. Don Quijote (USA) Co., Ltd (Order Dismissing Appeal for Lack of Appellate Jurisdiction). | Circuit Court, 1st Circuit (Civil) |
05/15/2013 | ICA | CAAP-12-0000395 [ADA] | State v. Bailey (s.d.o., affirmed). | Circuit Court, 1st Circuit (Robbery) |
05/15/2013 | S.Ct | SCWC-11-0000585 | State v. Ungounga (Order Dismissing Application for Writ of Certiorari). ICA s.d.o., filed 11/15/2012 [ada], 128 Haw. 475. Application for Writ of Certiorari, filed 04/02/2013. | Circuit Court, 1st Circuit |
05/14/2013 | S.Ct | SCWC-30559 [ADA] | State v. Pitts (Order Accepting Application for Writ of Certiorari and Ordering Supplemental Briefing). ICA s.d.o., filed 01/08/2013 [ada], 128 Haw. 499. Application for Writ of Certiorari, filed 04/17/2013. | Circuit Court, 1st Circuit |
05/14/2013 | S.Ct | 28826 [ADA] | Kutkowski v. Princeville Prince Golf Course, LLC. Opinion by C.J. Recktenwald Concurring in Part and Dissenting in Part [ada]. ICA Opinion, filed 03/20/2012 [ada], 128 Haw. 344. Concurring Opinion by J. Ginoza [ada]. Petitioner-Plaintiff-Appellant/Cross-Appellee Robert Kutkowaski's Application for Writ of Certiorari, filed 06/25/2012. S.Ct. Order Accepting Application for Writ of Certiorari, filed 08/01/2012 [ada]. | Circuit Court, 5th Circuit |
05/14/2013 | ICA | CAAP-12-0000159 [ADA] | State v. Aluli (s.d.o., affirmed in part, vacated, and remanded). | District Court, 1st Circuit, Ewa Division (DUI) |
05/13/2013 | S.Ct | Feb. 2013 Bar [ADA] | February 2013 Bar Examination Notice of Passing. |  |
05/10/2013 | S.Ct | SCWC-11-0000785 [ADA] | State v. Attaguile (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 02/13/2013 [ada], 129 Haw. 105. Application for Writ of Certiorari, filed 04/12/2013. | District Court, 2nd Circuit, Wailuku Division |
05/10/2013 | ICA | 30277 [ADA] | Kim-Alaniz v. Executive Center AOAO (s.d.o., affirmed). | Circuit Court, 1st Circuit (Civil) |
05/10/2013 | ICA | 30554 [ADA] | Huelo Hui v. Kili (s.d.o., affirmed). | Circuit Court, 2nd Circuit (Quiet Title) |
05/10/2013 | ICA | CAAP-12-0000451 [ADA] | State v. Peset (s.d.o., affirmed). | Circuit Court, 1st Circuit (Theft) |
05/10/2013 | S.Ct | SCWC-11-0000595 [ADA] | De La Garza v. State. ICA s.d.o., filed 07/20/2012 [ada], 128 Haw. 129. Petitioner's Application for Writ of Certiorari, filed 08/08/2012. S.Ct. Order Dismissing Application for Writ of Certiorari, filed 08/10/2012 [ada]. Petitioners Application for Writ of Certiorari, filed 09/10/2012. S.Ct. Order Accepting Application for Writ of Certiorari, filed 10/19/2012 [ada]. | Circuit Court, 2nd Circuit |
05/09/2013 | ICA | CAAP-11-0000755 [ADA] | Kono v. Abercrombie (Order Denying Defendant-Appellants/Cross-Appellees' Motion for Reconsideration). ICA mem.op., filed 04/24/2013 [ada]. Consolidated with No. CAAP-12-0000004. | Circuit Court, 1st Circuit |
05/09/2013 | ICA | CAAP-12-0000779 [ADA] | State v. Crosby (s.d.o., affirmed). | District Court, 3rd Circuit, Kona Division (DUI) |
05/09/2013 | ICA | CAAP-10-0000214 [ADA] | State v. Hsu (s.d.o., affirmed). | District Court, 1st Circuit, Honolulu Division (DUI) |
05/09/2013 | ICA | CAAP-12-0000524 [ADA] | First Hawaiian Bank v. Kamakea (s.d.o., affirmed). | Circuit Court, 3rd Circuit, Hilo Division (Foreclosure) |
05/09/2013 | ICA | CAAP-12-0000173 [ADA] | Federal National Mortgage Association v. Durate (s.d.o., affirmed). | District Court, 2nd Circuit (Ejectment) |
05/09/2013 | ICA | 30527 [ADA] | Simmons v. Samulewicz. | Circuit Court, 1st Circuit (Civil) |
05/09/2013 | S.Ct | SCWC-11-0000758 [ADA] | State v. Basham (Order Accepting Application for Writ of Certiorari). ICA s.d.o. filed 12/31/2012 [ada], 128 Haw. 499. Application for Writ of Certiorari, filed 03/28/2013. | Circuit Court, 1st Circuit |
05/09/2013 | ICA | CAAP-12-0001106 [ADA] | Trustees of the Estate of Bernice Pauahi Bishop v. BAC Home Loans Servicing, LP (Order Approving Defendant-Appellant's April 30, 2013 Stipulation for Dismissal of Appeal). | Circuit Court, 3rd Circuit |
05/09/2013 | S.Ct | SCWC-11-0000775 [ADA] | Van Ness v. State, Department of Education (Order Accepting Application for Writ of Certiorari). ICA mem.op., filed 12/10/2012 [ada], 128 Haw. 497. Application for Writ of Certiorari, filed 04/01/2013. | Labor and Industrial Relations Appeals Board |
05/08/2013 | ICA | CAAP-12-0000005 [ADA] | State v. Gustafson (s.d.o., affirmed). | District Court, 2nd Circuit, Wailuku Division (Criminal Trespass) |
05/08/2013 | ICA | CAAP-12-0000550 [ADA] | Nishi v. Department of Education, State of Hawaii (mem.op., vacated and remanded). Consolidated with No. CAAP-12-0000634. | Circuit Court, 1st Circuit (Employment Termination) |
05/08/2013 | S.Ct | SCWC-11-0000998 [ADA] | Association of Apartment Owners of the Waikoloa Beach Villas v. Sunstone Waikoloa, LLC ( Order Accepting Application for Writ of Certiorari). ICA Opinion, filed 01/29/2013 [ada], 129 Haw. 117. Application of Writ of Certiorari filed 03/28/2013. | Circuit Court, 3rd Circuit |
05/08/2013 | S.Ct | SCPW-13-0000017 [ADA] | Gowan v. Kubo (Order Granting in Part and Denying in Part Application for Writ of Mandamus). | Original Proceeding |
05/08/2013 | S.Ct | SCPW-13-0000286 [ADA] | State v. Slavick (Order Denying Petition for Writ of Habeas Corpus). | Original Proceeding |
05/08/2013 | S.Ct | SCPW-13-0000408 [ADA] | State v. Slavick (Order Denying Motion for Writ of Habeas Corpus). | Original Proceeding |
05/08/2013 | ICA | CAAP-12-0001062 | Ibbetson v. Kaiawe (Order Dismissing Appeal for Lack of Appellate Jurisdiction). | Circuit Court, 3rd Circuit |
05/08/2013 | S.Ct | SCWC-29688 [ADA] | State v. Pomroy (Order Accepting Application for Writ of Certiorari). ICA mem.op., filed 12/27/2012 [ada], 128 Haw. 498. Application for Writ of Certiorari, filed 03/27/2013. | District Court, 3rd Circuit, North and South Hilo Division |
05/08/2013 | ICA | CAAP-12-0001062 [ADA] | Ibbetson v. Kaiawe (Order Dismissing Appeal for Lack of Appellate Jurisdiction). | Circuit Court, 3rd Circuit |
05/07/2013 | ICA | CAAP-12-0000024 [ADA] | Federal National Mortgage Association v. Medeiros (mem. op., affirmed). | District Court, 3rd Circuit |
05/07/2013 | ICA | CAAP-12-0000106 [ADA] | State v. Nakano (Order Denying Motion for Reconsideration). | District Court, 1st Circuit |
05/07/2013 | ICA | 30241 [ADA] | Johnson v. State (amended mem. op., vacated in part, remanded and affirmed in part). ICA mem.op., filed 04/18/2013. | Circuit Court, 1st Circuit (Damages and Attorney's Fees) |
05/07/2013 | ICA | CAAP-12-0000802 [ADA] | Hawaiian Paradise Park Owners Association v. Mango Acres Trust (Order Dismissing Appeal). | District Court, 3rd Circuit |
05/07/2013 | ICA | CAAP-12-0001037 [ADA] | Diaz v. Whang (Order Denying Plaintiff Appellant's May 03, 2013 Motion for Reconsideration of Order Dismissing Appeal for Lack of Appellate Jurisdiction). ICA Order Dismissing Appeal for Lack of Appellate Jurisdiction, filed 04/26/2013 [ada]. Motion for Reconsideration, filed 05/03/0213. | District Court, 1st Circuit |
05/07/2013 | ICA | SCWC-11-0000647 [ADA] | State v. Albert (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 01/11/2013 [ada]. 128 Haw 500. Application for Writ of Certiorari, filed 04/08/2013. | Circuit Court, 1st Circuit (Assault) |
05/06/2013 | ICA | CAAP-12-0000535 [ADA] | Mikelson v. United Services Automobile Association (mem. op., vacated and remanded). Defendant-Appellant United Services Automobile Association's Motion for Partial Reconsideration of Memorandum Opinon, filed 05/15/2013. ICA Order Denying Motion for Partial Reconsideration of Memorandum Opinion, filed 05/22/2013 [ada]. | Circuit Court, 1st Circuit (Civil) |
05/06/2013 | ICA | CAAP-13-0000189 [ADA] | Ventura v. Wantman (Order Dismissing Appeal Pursuant to HRAP Rules 11(b)(2), (c)(2)). | District Court, 1st Circuit |
05/06/2013 | ICA | CAAP-12-0001035 [ADA] | Grisham v. Spadaro (Order Granting April 22, 2013 Motion to Dismiss Appeal). | District Court, 1st Circuit |
05/03/2013 | ICA | CAAP-12-0001107 [ADA] | Trotter v. State (Order Dismissing Appeal for Lack of Appellate Jurisdiction). | Circuit Court, 1st Circuit |
05/03/2013 | ICA | CAAP-12-0001005 [ADA] | Espiritu v. State (Order Dismissing Appeal Pursuant to HRAP Rule 30). | Circuit Court, 2nd Circuit |
05/03/2013 | ICA | 30694 [ADA] | AOAO Queen Emma Gardens v. Ma (Order Denying Appellees-Petitioners/Apellants' Motion for Partial Reconsideration). ICA mem.op., filed 04/05/2013 [ada]. ICA Order of Correction, filed 04/09/2013 [ada]. Petitioners/Appellants Tommy Wai Hung Ma and Sindy Yee Ma's Motion for Partial Reconsideration, filed 04/27/2013. | Circuit Court, 1st Circuit |
05/03/2013 | ICA | CAAP-12-0001023 [ADA] | McGrath Properties I, LLC v. Association of Apartment Owners of Lihue Townhouse (Order (1) Granting Defendants-Appellees' April 05, 2013 Motion to Dismiss Appeal by Plaintiff-Appellant McGrath Properties I, LLC, and (2) Granting Defendants-Appellees' April 16, 2013 Motion to Dismiss Appeal by Plaintiff-Appellant Suzanne Kitamura, as Custodian for DAF). ICA Order Granting the May 7, 2013 Motion to Dismiss Appeal, filed 05/21/2013 [ada]. | Circuit Court, 5th Circuit |
05/03/2013 | ICA | CAAP-12-0001054 [ADA] | Hausman v. McMillan (Order Granting March 18, 2013 Motion to Dismiss Appeal for Lack of Appellate Jurisdiction). | Circuit Court, 2nd Circuit |
05/03/2013 | ICA | CAAP-13-0000008 [ADA] | Thiessen v. Zoning Board of Appeals of the City and County of Honolulu (Order Dismissing Appeal for Lack of Appellate Jurisdiction). | Circuit Court, 1st Circuit |
05/03/2013 | ICA | CAAP-12-0001074 [ADA] | McClymonds v. Knauer (Order Dismissing Appeal Pursuant to HRAP Rule 30). | District Court, 1st Circuit |
05/02/2013 | S.Ct | SCAP-11-0000611 [ADA] | Kaleikini v. Yoshioka. S.Ct. Opinion, filed 08/24/2012 [ada], 128 Haw. 53. Motion for Reconsideration, filed 09/04/2012. S.Ct. Order Denying Motion for Reconsideration, filed 09/27/2012 [ada], 128 Haw. 199. Motion for Reconsideration, filed 05/10/2013. S.Ct. Order Denying Motion for Reconsideration, filed 05/17/2013 [ada]. | Circuit Court, 1st Circuit |
05/02/2013 | S.Ct | SCWC-11-0000550 [ADA] | State v. Cabinatan (Order Accepting Application for Writ of Certiorari). ICA s.d.o., filed 12/27/2012 [ada]. Application for Writ of Certiorari, filed 03/26/2013. | Circuit Court, 1st Circuit (Criminal) |
05/02/2013 | ICA | CAAP-13-0000067 [ADA] | Evans v. STR Painting, Inc. (Order Granting February 11, 2013 Motion to Dismiss Appeal for Lack of Appellate Jurisdiction). | Labor and Industrial Relations Appeals Board |
05/02/2013 | ICA | CAAP-12-0000772 [ADA] | Moore v. Mosier (Order Dismissing Appeal for Lack of Appellate Jurisdiction). | Circuit Court, 1st Circuit (Civil) |
05/02/2013 | S.Ct | SCPW-13-0000313 [ADA] | Travelocity.com LP v. Chang (Order Denying Motion). Petition for Mandamus, filed 03/28/2013. S.Ct. Order Denying without Prejudice Petition for Writ of Mandamus and Request for Immediate Stay of all Trial Proceedings, or, Alternatively, a Stay of the "Pay First" obligation under HRS 235-114, Pending Resolution of Petition, filed 04/22/2013 [ada]. Amended Petition for Writ of Mandamus, filed 04/19/2013. | Original Proceedings |
05/02/2013 | S.Ct | SCPW-13-0000387 [ADA] | Tierney v. Perkins (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 04/08/2013. | Original Proceedings |
05/01/2013 | S.Ct | SCWC-30484 [ADA] | In re Application of Honolulu Construction and Draying Company, Limited. vs. State (Order Accepting Application for Writ of Certiorari). ICA Opinion, filed 12/19/2012 [ada], 129 Haw. 68. Application for Writ of Certiorari, filed 03/19/2013. Petitioner's Scenic Hawaii, Inc.'s Application for Writ of Certiorari, filed 04/22/2013. | Land Court, 1st Circuit |
05/01/2013 | S.Ct | SCWC-28358 [ADA] | Pila‘a 400 LLC v. Board of Land and Natural Resources (Order Accepting Application for Writ of Certiorari). ICA mem.op., filed 12/21/2012 [ada], 128 Haw. 497. Concurring Opinion by Circuit Judge Wilson [ada]. Application for Writ of Certiorari, filed 03/18/2013. | Circuit Court, 5th Circuit (Civil) |
04/30/2013 | ICA | 29440 [ADA] | Kauai Springs, Inc. v. Planning Commission of the County of Kauai. | Circuit Court, 5th Circuit |
04/30/2013 | ICA | 29794 [ADA] | State v. Armitage (s.d.o., affirmed). Consolidated with Nos. 29795 and 29796. | District Court, 2nd Circuit, Wailuku Division (Native Hawaiian Rights) |
04/30/2013 | ICA | 29905 [ADA] | Wells Fargo Bank v. Himalaya-Fidele (s.d.o., affirmed). | Circuit Court, 1st Circuit (Ejectment) |
04/30/2013 | ICA | 30065 [ADA] | Imamoto v. Kahi Mohala Hospital (s.d.o., affirmed). | Circuit Court, 1st Circuit (Civil) |
04/30/2013 | ICA | 30281 [ADA] | Akaku: Maui Community Television v. Lopez (mem.op., affirmed). | Circuit Court, 2nd Circuit (Procurement) |
04/30/2013 | ICA | CAAP-11-0000374 [ADA] | State v. Amiral (s.d.o., affirmed). Dissenting Opinion by J. Nakamura [ada]. | District Court, 1st Circuit, Ewa Division (Traffic) |
04/30/2013 | ICA | CAAP-11-0000754 [ADA] | State v. Tupito (s.d.o., affirmed). | Circuit Court, 1st Circuit (Conviction and Sentence) |
04/30/2013 | ICA | CAAP-12-0000170 [ADA] | State v. Pieper (s.d.o., affirmed). | District Court, 1st Circuit, Honolulu Division (Assault) |
04/30/2013 | ICA | CAAP-12-0000368 [ADA] | Federal Home Loan Mortgage Corporation v. Griep (s.d.o., affirmed). | District Court, 5th Circuit (Judical Notice) |
04/30/2013 | ICA | CAAP-12-0000503 [ADA] | Deutsche Bank National Trust Company v. Pa‘a (s.d.o., affirmed). | District Court, 2nd Circuit, Wailuku Division (Possession) |
04/30/2013 | S.Ct | SCAD-12-0000822 [ADA] | Office of Disciplinary Counsel v. Eliason (Order of Reinstatement). S.Ct. Order of Suspension, filed 01/23/2013 [ada]. | Original Proceeding |
04/30/2013 | ICA | CAAP-11-0001037 [ADA] | Child Support Enforcement Agency, State of Hawaii v. MSH (mem.op., vacated and remanded). | Family Court, 1st Circuit (Child Support) |
04/29/2013 | ICA | 30488 [ADA] | International Display Systems, Inc. v. Okimoto, Director, Department of Transportation, State of Hawaii. | Circuit Court, 1st Circuit |
04/29/2013 | ICA | CAAP-12-0000711 [ADA] | Title Guaranty Escrow Services, Inc. v. Waialea Resort Company, Ltd. (Order of Correction). ICA Order (1) Denying March 12, 2013 Motion to Remand for Entry of Judgment and (2) Dismissing Appeal for Lack of Appellate Jurisdiction, filed 04/24/2013 [ada]. | Circuit Court, 2nd Circuit |
04/29/2013 | S.Ct | SCWC-11-0000085 [ADA] | State v. Cramer. Concurring Opinion by J. Acoba, with whom J. Pollack joins [ada]. ICA s.d.o., filed 05/03/2012 [ada], 127 Haw. 241. Application for Writ of Certiorari, filed 07/31/2012. S.Ct. Order Accepting Application for Writ of Certiorari, filed 09/06/2012 [ada]. | Circuit Court, 2nd Circuit |
04/29/2013 | S.Ct | SCPW-13-0000416 [ADA] | Tierney v. Liu (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 04/18/2013. | Original Proceeding |
04/29/2013 | S.Ct | SCWC-10-0000219 [ADA] | State v. Larsen (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 12/26/2012 [ada], 128 Haw. 478. Application for Writ of Certiorari, filed 03/26/2013. | District Court, 3rd Circuit, North and South Hilo Division |
04/26/2013 | ICA | 29987 [ADA] | Munoz v. Hata (mem.op., vacated and remanded). Dissenting Opinion by J. Leonard [ada]. | Circuit Court, 2nd Circuit (Lease and Eviction) |
04/26/2013 | ICA | CAAP-12-0000034 [ADA] | State v. Vailimi (mem.op., affirmed). | Circuit Court, 1st Circuit (Bail) |
04/26/2013 | ICA | CAAP-12-0000106 [ADA] | State v. Nakano (Order Granting Motion for Reconsideration). ICA s.d.o., filed 04/17/2013. Defendant-Appellant's Motion for Reconsideration, filed 04/18/2013. ICA s.d.o., filed 04/26/2013 [ada]. Defendant-Appellant's Motion for Reconsideration, filed 04/27/2013. | District Court, 1st Circuit, Honolulu Division |
04/26/2013 | ICA | CAAP-12-0000106 [ADA] | State v. Nakano (s.d.o., vacated and remanded). ICA s.d.o., filed 04/17/2013. Defendant-Appellant's Motion for Reconsideration, file 04/18/2013. ICA Order Granting Motion for Reconsideration, filed 04/26/2013 [ada]. Defendant-Appellant's Motion for Reconsideration, filed 04/27/2013. | District Court, 1st Circuit, Honolulu Division (DUI) |
04/26/2013 | ICA | CAAP-12-0000468 [ADA] | Stanton v. State (Order of Correction). ICA s.d.o., filed 02/28/2013 [ada], 129 Haw. 171. | Circuit Court, 1st Circuit |
04/26/2013 | ICA | CAAP-13-0000397 [ADA] | Snyder v. Snyder (Order Approving the April 17, 2013 Stipulation to Dismiss Appeal). | Family Court, 1st Circuit |
04/26/2013 | ICA | CAAP-12-0001037 [ADA] | Diaz v. Whang (Order Dismissing Appeal for Lack of Appellate Jurisdiction). Motion for Reconsideration, filed 05/03/2013. | District Court, 1st Circuit |
04/26/2013 | S.Ct | SCWC-11-0000426 [ADA] | Paglinawan v. Rompel (Order Dismissing Application for Writ of Certiorari). ICA mem.op., filed 03/18/2013 [ada]. Motion for Reconsideration, filed 03/27/2013. ICA Order Denying Plaintiff-Appellee's Motion for Reconsideration, filed 04/04/2013 [ada]. Application for Writ of Certiorari, filed 04/17/2013. | District Court, 1st Circuit |
04/26/2013 | S.Ct | SCPW-13-0000409 [ADA] | Benitez v. State (Order Denying Petition for Relief). Petition for Writ of Mandamus, filed 04/12/2013. | Original Proceeding |
04/26/2013 | S.Ct | 30639 [ADA] | Kobashigawa v. Silva. ICA Opinion, filed 12/02/2011 [ada], 126 Haw. 62. Application for Writ of Certiorari, filed 03/21/2012. S.Ct. Order Accepting Application for Writ of Certiorari, filed 05/04/2012 [ada]. | Circuit Court, 1st Circuit |
04/25/2013 | ICA | CAAP-11-0000606 [ADA] | Villanueva v. State (s.d.o., affirmed). | Circuit Court, 2nd Circuit (Criminal) |
04/25/2013 | ICA | CAAP-13-0000018 [ADA] | Federal Home Loan Mortgage Corporation v. Pardon (Order Dismissing Appeal for Lack of Jurisdiction). | Circuit Court, 1st Circuit |
04/25/2013 | ICA | 30114 [ADA] | McCully Associates v. Ten Grand Associates (s.d.o. affirmed). | Circuit Court, 1st Circuit (Civil) |
04/24/2013 | ICA | 30186 [ADA] | State v. Decoite (mem.op., vacated and remanded). | Family Court, 2nd Circuit |
04/24/2013 | ICA | 30152 [ADA] | Roaring Lion, LLC v. Exclusive Resorts PBL 1, LLC (mem.op., vacated and remanded). Consolidated with CAAP-12-0000003. | Circuit Court, 3rd Circuit |
04/24/2013 | ICA | CAAP-11-0000755 [ADA] | Kono v. Abercrombie (mem.op., vacated and remanded). Consolidated with No. CAAP-12-0000004. Motion for Reconsideration, filed 05/03/2013. ICA Order Denying Defendant-Appellants/Cross-Appellees' Motion for Reconsideration, filed 05/09/2013 [ada]. | Circuit Court, 1st Circuit |
04/24/2013 | ICA | CAAP-11-0001072 [ADA] | Roaring Lion, LLC v. Exclusive Resorts PBL1, LLC (mem.op., vacated and remamnded). | Circuit Court, 3rd Circuit |
04/24/2013 | ICA | CAAP-13-0000174 [ADA] | State v. Tokunaga (Order Granting Defendant-Appellant's April 11, 2013 Motion to Dismiss the Appeal). | District Court, 1st Circuit |
04/24/2013 | ICA | CAAP-12-0000711 [ADA] | Title Guaranty Escrow Services, Inc. v. Waialea Resort Company, Ltd. (Order (1) Denying March 12, 2013 Motion to Remand for Entry of Judgment and (2) Dismissing Appeal for Lack of Appellate Jurisdiction). ICA Order of Correction, filed 04/29/2013 [ada]. | Circuit Court, 2nd Circuit |
04/24/2013 | S.Ct | SCPW-13-0000186 [ADA] | Smith v. Nakamura (Order Denying without Prejudice Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 03/15/2013. | Original Proceeding |
04/24/2013 | S.Ct | SCPW-13-0000199 [ADA] | Tierney v. Sakai (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 03/18/2013. Motion for Reconsideration, filed 05/08/2013. S.Ct. Order Denying Motion for Reconsideration, filed 05/20/2013 [ada]. | Original Proceeding |
04/24/2013 | S.Ct | SCPW-13-0000402 [ADA] | Tierney v. Matsuoka (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 04/11/2013. Motion for Reconsideration, filed 05/08/2013. S.Ct. Order Denying Motion for Reconsideration, filed 05/20/2013 [ada]. | Original Proceeding |
04/24/2013 | S.Ct | SCWC-12-0000870 [ADA] | Association of Condominium Homeowners of Tropics at Waikele v. Sakuma (Order Accepting Amended Application for Writ of Certiorari). Dissenting Opinion by J. Nakayama [ada]. ICA Order Dismissing Appeal for Lack of Jurisdiction, filed 01/11/2013 [ada]. Petitioner Pro Se Patsy N. Sakuma's Application for Writ of Certiorari, filed 03/15/2013. S.Ct. Order Granting Motion for Leave of Court to File Conforming Application for Writ of Certiorari, filed 04/02/2013 [ada]. | Circuit Court, 1st Circuit |
04/22/2013 | ICA | CAAP-12-0000099 [ADA] | County of Hawaii v. H. Kimura Store, Inc. (s.d.o., affirmed). Application for Writ of Certiorari, filed 05/07/2013. S.Ct. Order Dismissing Application for Writ of Certiorari, filed 05/21/2013 [ada]. | Circuit Court, 3rd Circuit (Civil) |
04/22/2013 | ICA | CAAP-12-0000496 [ADA] | Wille v. Board of Land and Natural Resources (mem.op., affirmed). | Circuit Court, 3rd Circuit (Leases) |
04/22/2013 | ICA | CAAP-12-0001119 [ADA] | In re Application of Coral Wireless, LLC d/b/a Mobi PCS (Order Dismissing Appeal for Lack of Appellate Jurisdiction). | Public Utilities Commission |
04/22/2013 | ICA | CAAP-12-0000171 [ADA] | In re Claim of Roman v. Ito (mem.op., affirmed). | Circuit Court, 1st Circuit (Insurance) |
04/22/2013 | S.Ct | SCPW-13-0000313 [ADA] | Travelocity.Com LP v. Chang (Order Denying without Prejudice Petition for Writ of Mandamus and Request for Immediate Stay of all Trial Proceedings, or, Alternatively, a Stay of the "Pay First" obligation under HRS 235-114, Pending Resolution of Petition). Petition for Mandamus, filed 03/28/2013. Amended Petition for Writ of Mandamus, filed 04/19/2013. S.Ct. Order Denying Motion, filed 05/02/2013 [ada]. | Original Proceeding |
04/19/2013 | ICA | CAAP-12-0000056 [ADA] | In re Rightstar Related Cases (mem.op, affirmed). | Circuit Court, 1st Circuit (Civil) |
04/19/2013 | ICA | 30343 [ADA] | JS-L v. IS (s.d.o., affirmed). | Family Court, 5th Circuit (Custody) |
04/19/2013 | ICA | CAAP-12-0000996 [ADA] | Jumper v. Jumper (Order Granting Defendant-Appellant's April 4, 2013 Motion to Withdraw Appeal). | Family Court, 1st Circuit |
04/19/2013 | ICA | CAAP-12-0001093 [ADA] | Narumanchi v. Gunta (Order Dismissing Appeal for Lack of Appellant Jurisdiction). | Family Court, 1st Circuit |
04/19/2013 | ICA | CAAP-12-0001125 [ADA] | Robinson v. Takamine (Order Dismissing Appeal for Lack of Appellate Jurisdiction). | Circuit Court, 5th Circuit |
04/18/2013 | ICA | 30241 | Johnson v. State (mem.op., vacated in part, remanded in part as to special damages and attorney's fees, affirmed in all other respects). Amended ICA mem.op., filed 05/07/2013 [ada]. | Circuit Court, 1st Circuit (Damages and Attorney's Fees) |
04/17/2013 | ICA | CAAP-12-0000357 [ADA] | State v. Sabala (s.d.o., vacated and remanded). | District Court, 1st Circuit, Ewa Division (Traffic) |
04/17/2013 | ICA | CAAP-12-0000106 | State v. Nakano (s.d.o., affirmed and vacated as to HRS 291E-61(a)(1)). Defendant-Appellant's Motion for Reconsideration, file 04/18/2013. ICA Order Granting Motion for Reconsideration, filed 04/26/2013 [ada]. ICA s.d.o., filed 04/26/2013 [ada]. Defendant-Appellant's Motion for Reconsideration, filed 04/27/2013. | District Court, 1st Circuit, Honolulu Division (Traffic) |
04/17/2013 | S.Ct | SCAD-13-0000057 [ADA] | Office of Disciplinary Counsel v. Songstad (Order of Disbarment). | Original Proceeding |
04/17/2013 | ICA | CAAP-12-0000738 [ADA] | Grandinetti v. Eloy Police Department (Order Dismissing Appeal for Lack of Appellate Jurisdiction). | Circuit Court, 1st Circuit |
04/17/2013 | S.Ct | SCWC-11-0000317 [ADA] | Minton v. Quintal (Order Accepting Application for Writ of Certiorari). ICA mem.op., filed 11/29/2012 [ada], 128 Haw. 497. Petition for Writ of Certiorari, filed 03/04/2013. | Circuit Court, 1st Circuit |
04/17/2013 | S.Ct | SCWC-28762 [ADA] | District Council 50 of the International Union of Painters & Allied Trades v. Lopez. Concurring and Dissenting Opinion by Circuit Judge Kim, with whom Circuit Judge To‘oto‘o, joins [ada]. ICA mem.op., filed 07/26/2012 [ada], 128 Haw. 128. Application for Writ of Certiorari, filed 10/18/2012. S.Ct. Order Accepting Application for Writ of Certiorari, filed 12/03/2012 [ada]. J. Kim Dissenting. | Circuit Court, 1st Circuit |
04/16/2013 | S.Ct | SCWC-29868 [ADA] | Jou v. Schmidt. ICA s.d.o., filed 04/02/2012 [ada], 127 Haw. 3. Petitioner-Appellant-Provider Emerson M.F. Jou, M.D.'s Application for Writ of Certiorari, filed 04/30/2012. S.Ct. Order Dismissing Application for Writ of Certiorari, filed 05/04/2012 [ada]. Petitioner-Appellant-Provider Emerson M.F. Jou, M.D.'s Application for Writ of Certiorari, filed 05/14/2012. S.Ct. Order Accepting Application for Writ of Certiorari, filed 06/26/2012 [ada]. | Circuit Court, 1st Circuit |
04/15/2013 | S.Ct | SCWC-11-0000571 [ADA] | State v. Pacheco (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 11/30/2012 [ada], 128 Haw. 477. Application for Writ of Certiorari, filed 03/08/2013. | Circuit Court, 3rd Circuit |
04/15/2013 | ICA | 29729 [ADA] | Group Builders, Inc. v. Admiral Insurance Company (mem.op., affirmed). | Circuit Court, 1st Circuit (Insurance Coverage) |
04/15/2013 | ICA | CAAP-12-0001055 [ADA] | Ulmer v. Hunadi (Order Approving the Stipulation to Dismiss Appeal Filed on April 1, 2013). | District Court, 5th Circuit |
04/15/2013 | ICA | CAAP-12-0000295 [ADA] | Hawai‘i State Teachers Association v. University Laboratory School. | Circuit Court, 1st Circuit |
04/15/2013 | ICA | CAAP-12-0000406 [ADA] | Butler v. Myers (mem.op., affirmed). | Circuit Court, 2nd Circuit (Civil) |
04/15/2013 | ICA | CAAP-12-0000426 [ADA] | U.S. Bank National Association v. Miceli (Order Approving the March 26, 2013 Stipulation for Dismissal). | Circuit Court, 2nd Circuit |
04/15/2013 | ICA | CAAP-11-0000849 [ADA] | State v. Austin (Order Dismissing Appeal Pursuant to HRAP Rule 30). | Circuit Court, 1st Circuit |
04/15/2013 | ICA | CAAP-12-0001020 [ADA] | Stevens v. State (Order Dismissing Appeal Pursuant to HRAP Rule 30). | Circuit Court, 3rd Circuit |
04/12/2013 | ICA | CAAP-11-0001078 [ADA] | State v. Santiago (s.d.o., affirmed). Application for Writ of Certiorari, filed 05/16/2013. | Circuit Court, 1st Circuit (Criminal) |
04/12/2013 | ICA | CAAP-10-0000181 [ADA] | In re Marn Family Litigation (Order Denying Motion for Reconsideration). ICA s.d.o., filed 3/28/2013 [ada], 129 Haw. 269. Motion for Reconsideration, filed 04/08/2013. | Circuit Court, 1st Circuit |
04/11/2013 | ICA | 29946 [ADA] | State v. Rego (Order of Correction). ICA s.d.o., filed 02/14/2013 [ada], 129 Haw. 106. | Family Court, 1st Circuit |
04/11/2013 | ICA | CAAP-12-0001117 [ADA] | In re Application of T-Mobile West Corporation (Order Granting March 7, 2013 Motion to Dismiss Appeal for Lack of Appellate Jurisdiction). | Public Utilities Commission |
04/11/2013 | ICA | CAAP-12-0000544 [ADA] | Rapozo v. State (Order Dismissing Appeal Pursuant to HRAP Rule 30). | Circuit Court, 1st Circuit |
04/11/2013 | ICA | CAAP-12-0000883 [ADA] | Federal National Mortgage Association v. Amavisca (Order Dismissing Appeal Pursuant HRAP Rule 30). | District Court, 3rd Circuit |
04/11/2013 | ICA | CAAP-12-0001073 [ADA] | State v. Vaa (Order Dismissing Appeal Without Prejudice for Lack of Jurisdiction). Consolidated with CAAP-12-0001075. | District Court, 1st Circuit |
04/11/2013 | S.Ct | SCWC-11-0000344 [ADA] | State v. Pai (Order Accepting Application for Writ of Certiorari). ICA s.d.o., filed 11/26/2012 [ada], 128 Haw. 476. Application for Writ of Certiorari, filed 03/08/2013. | District Court, 2nd Circuit, Wailuku Division |
04/10/2013 | ICA | CAAP-12-0000622 [ADA] | Kong v. State (Order Dismissing Appeal Pursuant to HRAP Rule 30). | Circuit Court, 2nd Circuit |
04/10/2013 | S.Ct | SCPW-13-0000115 [ADA] | Tierney v. Perkins (Order Denying Motion for Reconsideration). S.Ct. Order Denying Petition for Writ of Mandamus, filed 03/20/2013 [ada]. Motion for Reconsideration, filed 04/04/2013. | Original Proceeding |
04/10/2013 | S.Ct | SCWC-11-0000444 [ADA] | Mortgage Electronic Registration Systems, Inc. v. Wise (Order Accepting Application for Writ of Certiorari). ICA s.d.o., filed 11/29/2012 [ada], 128 Haw. 476. Application for Writ of Certiorari, filed 03/04/2013. | Circuit Court, 1st Circuit (Civil) |
04/09/2013 | ICA | 30694 [ADA] | AOAO Queen Emma Gardens v. Ma (Order of Correction). ICA mem.op., filed 04/05/2013 [ada]. Petitioners/Appellants Tommy Wai Hung Ma and Sindy Yee Ma's Motion for Partial Reconsideration, filed 04/27/2013. ICA Order Denying Appellees-Petitioners/Apellants' Motion for Partial Reconsideration, filed 05/03/2013 [ada]. | Circuit Court, 1st Circuit |
04/09/2013 | ICA | CAAP-12-0000986 [ADA] | Middleton v. State of Hawaii, Department of Human Services (Order Dismissing Appeal for Lack of Jurisdiction). | Circuit Court, 1st Circuit |
04/09/2013 | S.Ct | SCWC-11-0000728 [ADA] | Wells Fargo Bank, N.A. v. Yamamoto (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 12/11/2012 [ada] 128 Haw. 477. Application for Writ of Certiorari, filed 02/25/2013. | Circuit Court, 1st Circuit |
04/09/2013 | ICA | CAAP-13-0000043 [ADA] | Sato v. Wahiawa-Central Oahu Health Center, Inc. (Order Approving the March 20, 2013 Stipulation of Voluntary Dismissal of Appeal). | Circuit Court, 1st Circuit |
04/09/2013 | ICA | CAAP-12-0000485 [ADA] | Grandinetti v. State (Order Denying Petitioner-Appellant's Proof of Service of Order (March 22, 2013), and Timely Reconsideration Application). ICA s.d.o., filed 03/22/2013 [ada]. Petitioner-Appellant's Proof of Service of Order (March 22, 2013), and Timely Reconsideration Application, filed 04/04/2013. Application for Writ of Certiorari, filed 04/29/2013. | Circuit Court, 1st Circuit |
04/09/2013 | ICA | CAAP-12-0001071 [ADA] | Saetung v. Royal Jade, Inc. (Order Dismissing Appeal). | Labor and Industrial Relations Appeals Board |
04/09/2013 | ICA | CAAP-12-0000641 [ADA] | Marn v. McCully Association (Order Dismissing the Appeal). | Circuit Court, 1st Circuit |
04/09/2013 | ICA | CAAP-12-0000781 [ADA] | Hall v. Capital One, N.A. (Order Dismissing Appeal for Lack of Appellate Jurisdiction). | Circuit Court, 1st Circuit |
04/09/2013 | ICA | CAAP-12-0000985 [ADA] | Indymac Venture, LLC v. Hillard (Order (1) Denying March 13, 2013 Motion for Extension of Time to File Opening Brief and (2) Dismissing Appeal for Lack of Appellate Jurisdiction). | Circuit Court, 2nd Circuit |
04/08/2013 | S.Ct | SCPW-13-0000130 [ADA] | Tierney v. State (Order Denying Motion for Reconsideration). Petition for Writ of Mandamus, filed 03/04/2013. S.Ct. Order, filed 03/20/2013 [ada]. Motion for Reconsideration, filed 04/04/2013. | Original Proceeding |
04/08/2013 | S.Ct | SCPW-13-0000140 [ADA] | Tierney v. State (Order Denying Motion for Reconsideration). Petition for Writ of Mandamus, filed 03/06/2013. S.Ct. Order, filed 03/20/2013 [ada]. Motion for Reconsideration, filed 04/04/2013. | Original Proceeding |
04/05/2013 | ICA | 30694 [ADA] | AOAO Queen Emma Gardens v. Ma (mem.op., vacated in part, affirmed in part, remanded). ICA Order of Correction, filed 04/09/2013 [ada]. Appellees-Petitioners/Appellants Tommy Wai Hung Ma and Sindy Yee Ma's Motion for Partial Reconsideration, filed 04/27/2013. ICA Order Denying Appellees-Petitioners/Apellants' Motion for Partial Reconsideration, filed 05/03/2013 [ada]. | Circuit Court, 1st Circuit (Condominium Bylaws) |
04/05/2013 | ICA | CAAP-12-0000080 [ADA] | Kellberg v. County of Hawai‘i (Order Denying Motion for Reconsideration). ICA s.d.o., filed 03/20/2013 [ada], 129 Haw. 268. Motion for Reconsideration, filed 04/01/2013. | Circuit Court, 3rd Circuit |
04/04/2013 | S.Ct | SCWC-11-0000760 [ADA] | State v. Robles (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 12/14/2012 [ada]. Application for Writ of Certiorari, filed 02/24/2013. | Circuit Court, 1st Circuit |
04/04/2013 | ICA | CAAP-11-0000426 [ADA] | Paglinawan v. Rompel (Order Denying Plaintiff-Appellee's Motion for Reconsideration). ICA mem.op., filed 03/18/2013 [ada]. Motion for Reconsideration, filed 03/27/2013. Application for Writ of Certiorari, filed 04/17/2013. S.Ct. Order Dismissing Application for Writ of Certiorari, filed 04/26/2013 [ada]. | District Court, 1st Circuit |
04/04/2013 | ICA | CAAP-11-0000778 [ADA] | Deutsche Bank National Trust Company v. Kaohelaulii (Order Denying Motion for Reconsideration). ICA s.d.o., filed 03/21/2013 [ada], 129 Haw. 268. Defendants-Appellants' Motion for Reconsideration, filed 03/27/2013. | District Court, 2nd Circuit |
04/03/2013 | ICA | CAAP-12-0000683 [ADA] | Aguiar v. Kauai Floors, Inc. (Order Dismissing Appeal Pursuant to HRAP Rule 30). | Labor and Industrial Relations Appeals Board |
04/03/2013 | ICA | CAAP-12-0001076 [ADA] | Clark Realty Corporation v. Henry F. Akona Trust (Order Approving the First Amended Stipulation for Dismissal filed on March 14, 2013). | Circuit Court, 3rd Circuit |
04/03/2013 | S.Ct | SCPW-12-00001124 [ADA] | State v. Salvick (Order Dismissing Motion for Reconsideration). S.Ct. Order Denying Petition for Writ of Prohibition, filed 01/23/2013 [ada]. Motion for Reconsideration, filed 03/27/2013. | Original Proceeding |
04/03/2013 | S.Ct | SCPW-13-0001127 [ADA] | State v. Slavick (Order Dismissing Motion for Reconsideration). S.Ct. Order Denying without Prejudice Motion for Habeas Corpus, filed 01/23/2013 [ada]. Motion for Reconsideration, filed 02/07/2013. S.Ct. Order Denying Motion for Reconsideration, filed 02/19/2013 [ada]. Motion for Reconsideration, filed 03/27/2013. | Original Proceeding |
04/02/2013 | ICA | CAAP-12-0000119 [ADA] | Jou v. Siu (Order Denying Plaintiff-Appellant's Motion for Partial Reconsideration). ICA mem. op. filed 03/22/2013 [ada]. Motion for Partial Reconsideration, filed 03/25/2013. Application for Writ of Certiorari, filed 05/17/2013. | Circuit Court, 1st Circuit |
04/02/2013 | S.Ct | SCWC-12-0000870 [ADA] | Association of Condominium Homeowners of Tropics at Waikele v. Sakuma (Order Granting Motion for Leave of Court to File Conforming Application for Writ of Certiorari). ICA Order Dismissing Appeal for Lack of Jurisdiction, filed 01/11/2013 [ada]. Petitioner Pro Se Patsy N. Sakuma's Application for Writ of Certiorari, filed 03/15/2013. S.Ct. Order Accepting Amended Application for Writ of Certiorari, filed 04/24/2013 [ada]. Dissenting Opinion by J. Nakayama [ada]. | Circuit Court, 1st Circuit |
04/01/2013 | S.Ct | SCPW-13-0000079 [ADA] | Tierney v. Matsuoka (Order Denying Motion for Reconsideration). Petition for Writ of Mandamus, filed 02/07/2013. S. Ct. Order Denying Petition for Writ of Mandamus, filed 03/22/2013 [ada]. Motion for Reconsideration, filed 03/22/2013. | Original Proceeding |
04/01/2013 | S.Ct | SCPW-13-0000080 [ADA] | Tierney v. Espinda (Order Denying Motion for Reconsideration). S.Ct. Order Denying Petition for Writ of Mandamus, filed 03/14/2013 [ada]. Motion for Reconsideration, filed 03/22/2013. | Original Proceeding |
04/01/2013 | S.Ct | SCPW-12-0000831 [ADA] | Tierney v. Sakai (Order Denying Motion for Reconsideration). Petition for Writ of Mandamus, filed 10/02/2012. S.Ct. Order Denying without Prejudice Petition for Writ of Mandamus, filed 11/01/2012 [ada]. Petition for Writ of Mandamus, filed 12/27/2012. S.Ct. Order Denying Petition for Writ of Mandamus, filed 01/24/2013 [ada]. Motion for Reconsideration, filed 02/07/2013. Petition for Writ of Mandamus for Emergency Medical and Dental Treatment, filed 02/08/2013. S.Ct. Order Denying Motion for Reconsideration, filed 02/19/2013 [ada]. S.Ct. Order Petition for Writ of Mandamus, filed 03/13/2013 [ada]. Motion for Reconsideration, filed 03/22/2013. | Original Proceeding |
03/28/2013 | ICA | CAAP-12-0001089 [ADA] | KB Resort Holdings v. Cades Schutte LLP (Order Granting Jan 31, 2013 Motion to Dismissing Interlocutory Appeal for Lack of Appelate Jurisdiction). | Circuit Court, 1st Circuit |
03/28/2013 | ICA | CAAP-11-0000736 [ADA] | State v. Ohashi (s.d.o., affirmed). | Circuit Court, 1st Circuit (Criminal) | 129 Haw. 269
03/28/2013 | ICA | CAAP-12-0000089 [ADA] | Wells Fargo Bank v. Hensley (s.d.o., affirmed). Application for Writ of Certiorari, filed 05/07/2013. | Circuit Court, 5th Circuit (Ejectment) | 129 Haw. 269
03/28/2013 | ICA | CAAP-12-0000112 [ADA] | State v. Malinay (s.d.o., affirmed). | Circuit Court, 1st Circuit (Assault) | 129 Haw. 269
03/28/2013 | ICA | CAAP-12-0000382 [ADA] | Ticor Title Insurance Company v. Mau (mem. op., affirmed in part and reversed in part). | Circuit Court, 2nd Circuit (Real Estate Dispute) |
03/28/2013 | ICA | CAAP-11-0001065 [ADA] | In the interest of AS. | Family Court, 1st Circuit |
03/28/2013 | ICA | CAAP-10-0000109 [ADA] | State v. Villiarimo (s.d.o., affirmed). | Family Court, 2nd Circuit (Revocation of Probation) | 129 Haw. 269
03/28/2013 | ICA | CAAP-10-0000181 [ADA] | In re Marn Family Litigation (s.d.o., dismissed). Motion for Reconsideration, filed 04/08/2013. ICA Order Denying Motion for Reconsideration, filed 04/12/2013 [ada]. | Circuit Court, 1st Circuit (Civil) | 129 Haw. 269
03/28/2013 | ICA | CAAP-12-0000548 [ADA] | State v. Speer (s.d.o., affirmed). | District Court, 1st Circuit, Honolulu Division (Traffic) | 129 Haw. 269
03/28/2013 | S.Ct | SCWC-11-0000048 [ADA] | State v. Transfiguracion (Order Rejecting Application for Certiorari). Dissenting Opinion by J. Acoba with whom J. Pollack joins [ada]. ICA s.d.o. filed 11/21/2012 [ada], 128 Haw. 476. Application for Writ of Certiorari, filed 02/11/2013. | Circuit Court, 3rd Circuit |
03/28/2013 | S.Ct | SCWC-11-0001026 [ADA] | Olson v. Lui (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 11/28/2012 [ada]. Consolidated with Nos. CAAP-11-0000629 and CAAP-11-0000489. Abel Lui's Application for Writ of Certiorari, filed 02/11/2013. | Disctrict Court, 3rd Circuit, Kau Division |
03/28/2013 | S.Ct | SCWC-11-0000369 [ADA] | Plauche v. Plauche (Order Dismissing Application for Writ of Certiorari). ICA s.d.o., filed 01/24/2013 [ada], 129 Haw. 29. Plaintiff-Appellant Jeffrey J. Plauche's Motion for Reconsideration of Summary Disposition Order filed on January 24, 2013, filed 02/01/2013. ICA Order Denying Motion for Reconsideration of Summary Disposition Order filed on January 24, 2013, filed 02/06/2013 [ada]. Application for Writ of Certiorari, filed 03/24/2013. Application for Writ of Certiorari, filed 04/29/2013. | Family Court, 2nd Circuit |
03/27/2013 | ICA | CAAP-11-0000644 [ADA] | State v. Hern. Consolidated with CAAP-12-0000528. ICA Order of Correction, filed 05/17/2013 [ada]. | District Court, 1st Circuit, Honolulu Div. |
03/27/2013 | ICA | 30467 [ADA] | Thomas v. Sterns (mem.op., affirmed). J. Leonard concurring separately. | Circuit Court, 3rd Circuit, Hilo Div. (Legal Malpractice) |
03/25/2013 | S.Ct | SCWC-11-0000793 [ADA] | State v. Schlesinger (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 11/30/2012 [ada] 128 Haw. 477. Petition for Writ of Certiorari, filed 02/08/2013. | Circuit Court, 3rd Circuit, Kona Div. |
03/22/2013 | ICA | CAAP-12-0000119 [ADA] | Jou v. Siu (mem.op., vacated and remanded). Motion for Partial Reconsideration, filed 03/25/2013. ICA Order Denying Plaintiff-Appellant's Motion for Partial Reconsideration, filed 04/02/2013 [ada]. Application for Writ of Certiorari, filed 05/17/2013. | Circuit Court, 1st Circuit (False Representation) |
03/22/2013 | ICA | CAAP-12-0000485 [ADA] | Grandinetti v. State (s.d.o., affirmed). Petitioner-Appellant's Proof of Service of Order (March 22, 2013), and Timely Reconsideration Application, filed 04/04/2013. ICA Order Denying Petitioner-Appellant's Proof of Service of Order (March 22, 2013), and Timely Reconsideration Application, filed 04/09/2013 [ada]. Application for Writ of Certiorari, filed 04/29/2013. | Circuit Court, 1st Circuit (Criminal) |
03/22/2013 | S.Ct | SCWC-10-0000037 [ADA] | State v. Scott (Order Accepting Application for Writ of Certiorari). ICA s.d.o., filed 12/17/2012 [ada]. Petitioner/Defendant-Appellant Scott's Application for Writ of Certiorari, filed 02/13/2013. | Circuit Court, 3rd Circuit (Criminal) |
03/22/2013 | S.Ct | SCWC-29703 [ADA] | State v. Pacquing. Dissenting Opinion by J. Acoba [ada]. ICA mem.op., filed 01/25/2012 [ada], 126 Haw. 265. Application for Writ of Certiorari, filed 04/23/2012. S.Ct. Order Accepting Application for Writ of Certiorari, filed 06/05/2012 [ada]. | Circuit Court, 1st Circuit | 129 Haw. 172
03/21/2013 | S.Ct | SCPW-13-0000078 [ADA] | Tierney v. Perkins (Order Denying Motion for Reconsideration). Petition for Writ of Mandamus, filed 02/07/2013. S.Ct. Order Denying Petition for Writ of Mandamus, filed 03/04/2013 [ada]. Motion for Reconsideration, filed 03/18/2013. | Original Proceeding |
03/21/2013 | ICA | 30070 [ADA] | Collins v. Wassell (s.d.o., affirmed). Dissenting opinion, J. Reifurth [ada]. | Family Court, 3rd Circuit (Divorce) |
03/21/2013 | ICA | CAAP-11-0001013 [ADA] | Federal National Mortgage Association v. Franco (Order Dismissing Appeal Pursuant to HRAP Rule 30). | District Court, 2nd Circuit |
03/21/2013 | ICA | CAAP-11-0000778 [ADA] | Deutsche Bank National Trust Company v. Kaohelaulii (s.d.o., affirmed). Defendants-Appellants' Motion for Reconsideration, filed 03/27/2013. ICA Order Denying Motion for Reconsideration, filed 04/04/2013 [ada]. | District Court, 2nd Circuit (Possession) | 129 Haw. 268
03/21/2013 | ICA | 29352 [ADA] | State v. Hawaii Government Employees Association, AFSCME Local No. 152, AFL-CIO (Order of Correction). ICA mem.op., filed 02/27/2013 [ada], 129 Haw. 170. Concurring and Dissenting Opinion by J. Nakamura [ada]. | Circuit Court, 1st Circuit |
03/21/2013 | S.Ct | SCWC-28917 [ADA] | NST Holdings Corp. v. Altres. Inc. (Order Approving Stipulation for Dismissal). ICA mem. op., filed 09/21/2012 [ada], 128 Haw. 310. Application for Writ of Certiorari, filed 12/03/2012. S.Ct. Order Accepting Application for Writ of Certiorari, filed 01/16/2013 [ada]. | Circuit Court, First Circuit (Civil) |
03/21/2013 | S.Ct | SCWC-11-0000512 [ADA] | Lopez v. State (Order Accepting Application for Writ of Certiorari). ICA mem.op., filed 11/13/2013 [ada] 128 Haw. 497. Application for Writ of Certiorari, filed 02/08/2013. | Circuit Court, 1st Circuit |
03/20/2013 | S.Ct | SCAD-12-0001028 [ADA] | Office of Disciplinary Counsel v. Hayashi (Order). S.Ct. Order of Reinstatement, filed 05/21/2013 [ada]. | Original Proceeding |
03/20/2013 | ICA | CAAP-12-0000080 [ADA] | Kellberg v. County of Hawaii (s.d.o., affirmed). Motion for Reconsideration, filed 04/01/2013. ICA Order Denying Motion for Reconsideration, filed 04/05/2013 [ada]. | Circuit Court, 3rd Circuit (Civil) | 129 Haw. 268
03/20/2013 | ICA | CAAP-12-0000092 [ADA] | State v. Puga (s.d.o., affirmed). | Circuit Court, 1st Circuit (Conviction and Sentence) | 129 Haw. 268
03/20/2013 | ICA | CAAP-12-0001088 [ADA] | Mundon v. State (Order Granting Respondent-Appellee State of Hawaii's Motion to Dismiss Petitioner-Appellant's Appeal). | Circuit Court, 5th Circuit |
03/20/2013 | ICA | 29570 [ADA] | Martin v. C. Brewer and Company, Ltd. (Order Denying Motion for Reconsideration). ICA s.d.o., filed 02/21/2013 [ada], 129 Haw. 106. Plaintiff-Appellant/Cross-Appellee Gail Martin's Motion for Reconsideration, filed 03/04/2013. | Circuit Court, 3rd Circuit |
03/20/2013 | S.Ct | SCPW-13-0000115 [ADA] | Tierney v. Perkins (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 02/27/2013. | Original Proceeding |
03/20/2013 | S.Ct | SCPW-13-0000130 [ADA] | Tierney v. State (Order). Petition for Writ of Mandamus, filed 03/04/2013. Motion for Reconsideration, filed 04/04/2013. S.Ct. Order Denying Motion for Reconsideration, filed 04/08/2013 [ada]. | Original Proceeding |
03/20/2013 | S.Ct | SCPW-13-0000140 [ADA] | Tierney v. Sakai (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 03/06/2013. Motion for Reconsideration, filed 04/04/2013. S.Ct. Order Denying Motion for Reconsideration, filed 04/08/2013 [ada]. | Original Proceeding |
03/19/2013 | S.Ct | SCWC-10-0000212 [ADA] | State v. Million (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 11/30/2012 [ada], 128 Haw. 477. Dissenting Opinion by J. Reifurth [ada]. Application for Writ of Certiorari, filed 12/27/2012. S.Ct. Order Dismissing Application for Writ of Certiorari, filed 01/07/2013 [ada]. Application for Writ of Certiorari, filed 02/07/2013. | Circuit Court, 3rd Circuit |
03/19/2013 | S.Ct | SCPW-13-0000167 [ADA] | Slavick v. Ahn (Order Denying without Prejudice Petition for Writ of Mandamus). | Original Proceeding |
03/19/2013 | S.Ct | SCWC-30518 [ADA] | State v. Metcalfe. Dissenting Opinion by J. Acoba, with whom J. Sakamoto joins [ada]. ICA mem.op., filed 03/30/2012 [ada]. Application for Writ of Certiorari, filed 06/23/2012. S.Ct. Order Accepting Application for Writ of Certiorari, filed 08/08/2012 [ada]. | Circuit Court, 3rd Circuit | 129 Haw. 206
03/19/2013 | ICA | CAAP-11-0000658 [ADA] | State v. Jackson (s.d.o., affirmed). | Circuit Court, 3rd Circuit (Manslaughter) | 129 Haw. 268
03/19/2013 | ICA | CAAP-11-0000670 [ADA] | State v. Cantrell (s.d.o., affirmed). | Circuit Court, 1st Circuit (Sexual Assault) |
03/19/2013 | ICA | CAAP-11-0000959 [ADA] | Kalacinski v. Dunkle (s.d.o., affirmed). Consolidated with No. CAAP-11-0001098. | Family Court, 1st Circuit (Domestic Abuse) | 129 Haw. 268
03/19/2013 | S.Ct | SCWC-11-0000157 [ADA] | Suzuki v. State (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 10/31/2012 [ada], 128 Haw. 313. Application for Writ of Certiorari, filed 02/05/2013. | Circuit Court, 1st Circuit |
03/18/2013 | ICA | CAAP-11-0000426 [ADA] | Paglinawan v. Rompel (mem.op., affirmed, attorneys' fees and cost are vacated and remanded). Motion for Reconsideration, filed 03/27/2013. ICA Order Denying Plaintiff-Appellee's Motion for Reconsideration, filed 04/04/2013 [ada]. Application for Writ of Certiorari, filed 04/17/2013. S.Ct. Order Dismissing Application for Writ of Certiorari, filed 04/26/2013 [ada]. | District Court, 1st Circuit (Possession) |
03/18/2013 | ICA | CAAP-12-0000009 [ADA] | State v. Getz (s.d.o., affirmed). | Circuit Court, 1st Circuit (Conviction and Sentence) | 129 Haw. 268
03/18/2013 | ICA | CAAP-12-0000144 [ADA] | Wells Fargo Bank N.A. v. Armitage (s.d.o., affirmed). | District Court, 3rd Circuit (Possession) |
03/18/2013 | ICA | 30691 [ADA] | Befitel v. Lyckman (mem.op., affirmed). Petitioner/Defendant and Third-Party Defendant-Appellant Diana Kiana Application for Writ of Certiorari, filed 04/17/2013. | Circuit Court, 1st Circuit (Good Faith Settlement) |
03/18/2013 | S.Ct | SCAD-12-0000414 [ADA] | Office of Disciplinary Counsel v. Ng (Order Denying Motion for Reconsideration). S.Ct. Order of Suspension, filed 03/01/2013 [ada]. Request for Reconsideration, filed 03/08/2013. | Original Proceeding |
03/18/2013 | ICA | CAAP-12-0000776 [ADA] | State v. Hastings (Order Granting Defendant-Appellant's March 6, 2013 Motion to Dismiss Appeal). | District Court, 1st Circuit |
03/15/2013 | S.Ct | SCAP-30686 [ADA] | Eastern Savings Bank, FSB v. Esteban. | Circuit Court, 5th Circuit | 129 Haw. 154
03/15/2013 | S.Ct | SCPW-13-0000079 [ADA] | Tierney v. Matsuoka (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 02/07/2013. Motion for reconsideration, filed 03/22/2013. S.Ct. Order Denying Motion for Reconsideration, filed 04/01/2013 [ada]. | Original Proceeding |
03/15/2013 | ICA | 30294 [ADA] | Makila Land Co., LLC v. Dizon (s.d.o., affirmed). | Circuit Court, 2nd Circuit (Land Title) | 129 Haw. 268
03/15/2013 | ICA | CAAP-11-0000958 [ADA] | Kerr v. Silva (s.d.o., affirmed). | District Court, 1st Circuit, Ko‘olau Poko Division (Harassment) | 129 Haw. 268
03/15/2013 | ICA | CAAP-12-0000035 [ADA] | Bennett v. County of Maui, Maui Police Department (s.d.o., affirmed). | Labor and Industrial Relations Appeals Board (Workers Compensation) | 129 Haw. 268
03/15/2013 | ICA | CAAP-12-0000164 [ADA] | Federal National Mortgage Association v. Bise (s.d.o., affirmed). | Circuit Court, 2nd Circuit (Possession) | 129 Haw. 268
03/15/2013 | S.Ct | SCWC-11-0000346 [ADA] | Jason Burnside, Trustee of the Audrey K. Burnside Revocable Living Trust Dated Jan. 21, 1998 by and through his Managing Agent Scott Real Estate, Inc. v. Cadiente (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 10/31/2012 [ada], 128 Haw. 313. Application for Writ of Certiorari, filed 01/29/2013. | District Court, 1st Circuit, Honolulu Division |
03/15/2013 | S.Ct | SCWC-11-0000031 [ADA] | State v. Kekona (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 10/24/2012 [ada], 128 Haw. 312. Application for Writ of Certiorari, filed 02/01/2013. | Circuit Court, 1st Circuit |
03/15/2013 | ICA | 29851 [ADA] | Abadilla v. Iwata (Order of Correction). ICA mem. op., filed 01/31/2013 [ada]. Petitioner-Appellee-Defendant Sanford Iwata's Application for Writ of Certiorari, filed 04/12/2013. | Circuit Court, 3rd Circuit |
03/14/2013 | ICA | 30123 [ADA] | Avelo Mortgage, LLC v. Segundo (Order of Correction). ICA s.d.o., filed 01/31/2013 [ada], 129 Haw. 105. ICA Amended Order of Correction, filed 03/14/2013 [ada]. | Circuit Court, 2nd Circuit |
03/14/2013 | ICA | CAAP-11-0001104 [ADA] | U.S. Bank National Association, as Trustee, on Behalf of the Holders of the Asset Backed Securities Corporation Home Equity Loan Trust, Series NC 2005-HE8, Asset Backed Pass-Trhough Certificates, Series NC 2005-HE8 v. Castro (mem.op., vacated and remanded). | District Court, 2nd Circuit (Possession) |
03/14/2013 | ICA | CAAP-12-0000743 [ADA] | Corless v. Ebay, Inc. (Order Dismissing Appeal for Lack of Appellate Jurisdiction). | Circuit Court, 1st Circuit |
03/14/2013 | ICA | 30123 [ADA] | Avelo Mortgage, LLC v. Segundo (Amended Order of Correction). ICA s.d.o., filed 01/31/2013 [ada], 129 Haw. 105. ICA Order of Correction, filed 03/14/2013 [ada]. | Circuit Court, 2nd Circuit |
03/14/2013 | S.Ct | SCWC-11-0000463 [ADA] | Thomas v. County of Hawaii (Order Rejecting Application for Writ of Certiorari). ICA mem.op., filed 10/26/2012 [ada], 128 Haw. 497. Application for Writ of Certiorari by Plaintiff-Appellant Jack Thomas, filed 02/01/2013. | Circuit Court, 3rd Circuit |
03/14/2013 | S.Ct | SCPW-13-0000080 [ADA] | Tierney v. Espinda (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 02/07/2013. Motion for Reconsideration, filed 03/22/2013. Order Denying Motion for Reconsideration, filed 04/01/2013 [ada]. | Original Proceeding |
03/13/2013 | S.Ct | SCWC-11-0000472 [ADA] | Knight v. State (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 12/07/2012 [ada], 128 Haw. 477. Application for Writ of Certiorari, filed 12/31/2012. S.Ct. Order Dismissing Application for Writ of Certiorari, filed 01/10/2013 [ada]. Application for Writ of Certiorari, filed 01/28/2013. | Circuit Court, 1st Circuit |
03/13/2013 | ICA | CAAP-12-000997 [ADA] | Sato v. Wahiawa-Central Oahu Health Center, Inc. (Order Approving Stipulation of Voluntary Dismissal of Appeal). | Circuit Court, 1st Circuit |
03/13/2013 | ICA | CAAP-12-0000760 [ADA] | Onewest Bank, F.S.B. v. Katonah Development LLC (Order Approving Stipulation for Voluntary Dismissal of Appeal). | Circuit Court, 3rd Circuit |
03/13/2013 | ICA | CAAP-12-0000435 [ADA] | State v. Shomour (s.d.o., affirmed). | Circuit Court, 1st Circuit (Criminal) | 129 Haw. 268
03/13/2013 | ICA | 30644 [ADA] | Lahaina Fashions, Inc. v. Bank of Hawaii (Order Denying Motion for Reconsideration). ICA Opinion, filed 02/21/2013 [ada], 129 Haw. 250. Appellant's Motion for Reconsideration, filed 03/04/2013. | Circuit Court, 2nd Circuit |
03/13/2013 | S.Ct | SCPW-12-0000831 [ADA] | Tierney v. Sakai (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 10/02/2012. S.Ct. Order Denying Without Prejudice Petition for Writ of Mandamus, filed 11/01/2012 [ada]. Petition for Writ of Mandamus, filed 12/27/2012. S.Ct. Order Denying Petition for Writ of Mandamus, filed 01/24/2013 [ada]. Motion for Reconsideration, filed 02/07/2013. Petition for Writ of Mandamus for Emergency Medical and Dental Treatment, filed 02/08/2013. S.Ct. Order Denying Motion for Reconsideration, filed 02/19/2013 [ada]. S.Ct. Order Denying Petition for Writ of Mandamus, filed 03/13/2013 [ada]. Motion for Reconsideration, filed 03/22/2013. S.Ct. Order Denying Motion for Reconsideration, filed 04/01/2013 [ada]. | Original Proceeding |
03/13/2013 | S.Ct | SCPW-13-0000095 [ADA] | Tierney v. State (Order Denying Motion for Reconsideration). S.Ct. Order Denying Petition for Writ of Mandamus, filed 02/21/2013 [ada]. Motion for Reconsideration, filed 03/04/2013. Motion for Reconsideration, filed 05/08/2013. S.Ct. Order Denying Motion for Reconsideration, filed 05/20/2013 [ada]. | Original Proceeding |
03/12/2013 | ICA | CAAP-11-0000806 [ADA] | Peck v. Kuiper (s.d.o., affirmed). | Family Court, 2nd Circuit (TRO) | 129 Haw. 171
03/12/2013 | ICA | CAAP-12-0001019 [ADA] | State v. Martinez (Order Granting Appellant State of Hawaii's March 1, 2013 Motion to Dismiss Appeal). | Circuit Court, 5th Circuit |
03/11/2013 | ICA | CAAP-12-0000742 [ADA] | State v. Sales (Order Granting Motion for Leave to Withdraw Appeal). | Circuit Court, 1st Circuit |
03/08/2013 | ICA | 29553 [ADA] | Nakajima v. Nakajima (Order Denying "Plaintiff/Cross-Defendant-Appellant's Motion for Reconsideration of the Court's Order Dismissing Appeal filed on February 22, 2013). C.J. Nakamura Dissenting. ICA Order Dismissing Appeal, filed 02/22/2013 [ada]. Dissenting Opinion by J. Nakamura [ada]. Plaintiff/Cross-Defendant-Appellant's Motion for Reconsideration of the Court's Order Dismissing Appeal, filed 03/04/2013. Application for Writ of Certiorari, filed 04/09/2013. S.Ct. Order Accepting Application for Writ of Certiorari, filed 05/21/2013 [ada]. | Family Court, 2nd Circuit |
03/08/2013 | ICA | 29838 [ADA] | Naito v. Naito (Order Denying Motion for Reconsideration). ICA s.d.o., filed 02/21/2013 [ada], 129 Haw. 106. Motion to Reconsider Summary Disposition Order, filed 02/21/2013. | Circuit Court, 1st Circuit |
03/08/2013 | ICA | CAAP-12-0000982 [ADA] | Alao v. Onewest Bank FSB (Order Granting January 24, 2013 Motion to Dismiss Appeal for Lack of Appellate Jurisdiction). Application for Writ of Certiorari, filed 05/07/2013. | Circuit Court, 1st Circuit |
03/08/2013 | S.Ct | SCWC-11-0000702 [ADA] | State v. Spearman (Order Denying Motion for Reconsideration). ICA s.d.o., filed 06/27/2012 [ada], 127 Haw. 414. Petitioner-Defendant-Appellant Sarah V.P. Spearman's Petition for Certiorari, filed 09/24/2012. S.Ct. Order Accepting Application for Writ of Certiorari, filed 11/08/2012 [ada]. S.Ct. Opinion, filed 02/21/2013 [ada], 129 Haw. 146. Petitioner-Defendant-Appellant Sarah V.P. Spearman's Motion for Reconsideration, filed 03/01/2013. | District Court 1st Circuit | 129 Haw. 163
03/08/2013 | S.Ct | SCPW-13-0000001 [ADA] | Tierney v. Liu (Order Denying Motion for Reconsideration). S.Ct. Order Denying Petition for Writ of Mandamus, filed 02/19/2013 [ada]. Petition for Writ of Mandamus, filed 01/04/2013. Motion for Reconsideration, filed 02/19/2013. | Original Proceeding |
03/06/2013 | S.Ct | SCPW-13-0000038 [ADA] | Smith v. Tanaka (Order Denying Petition for Writ of Mandamus and/or Prohibition). | Original Proceeding |
03/06/2013 | S.Ct | SCPW-13-0000082 [ADA] | Grandinetti v. Bobby Ross Group, Inc. (BRG) (Order). | Original Proceeding |
03/06/2013 | S.Ct | 30446 [ADA] | State v. Menendez (Order Accepting Application for Writ of Certiorari). ICA s.d.o., filed 12/10/2012 [ada]. Respondent-Defendant-Appellant's Application for Writ of Certiorari, filed 01/29/2013. | District Court, 1st Circuit, Wahiawa Division |
03/06/2013 | ICA | 30391 [ADA] | State v. Austin (mem.op., affirmed). | Circuit Court, 1st Circuit (Reduction of Sentence) |
03/06/2013 | ICA | CAAP-12-0001051 [ADA] | Shiosaki v. Jackson (Order Approving Stipulation to Dismiss Appeal). | Circuit Court, 1st Circuit |
03/06/2013 | ICA | CAAP-13-0000027 [ADA] | Eckerle v. Lauster (Order Approving the February 25, 2013 Stipulation for Dismissal of Appeal). | Circuit Court, 3rd Circuit |
03/06/2013 | S.Ct | SCWC-11-0000126 [ADA] | State v. Manipon-Silva (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 10/26/2012 [ada], 128 Haw. 312. Application for Writ of Certiorari, filed 01/25/2013. | Circuit Court, 1st Circuit |
03/05/2013 | S.Ct | 29520 [ADA] | State v. Maharaj (Order Accepting Application for Writ of Certiorari). ICA s.d.o., filed 10/25/2012 [ada], 128 Haw. 312. Defendant-Appellant's Motion for Reconsideration, filed 11/05/2012. ICA Order Denying Defendant-Appellant's Motion for Reconsideration, filed 11/14/2012 [ada]. Application for Writ of Certiorari, filed 01/21/2013. | District Court, 1st Circuit, Honolulu Division |
03/04/2013 | ICA | CAAP-12-0000837 [ADA] | Oceanic Companies, Inc. v. Kukui‘ula Development Company (Hawaii), LLC (Order Granting December 3, 2012 Motion to Dismiss Appeal for Lack of Appellate Jurisdiction). | Circuit Court, 1st Circuit |
03/04/2013 | ICA | CAAP-12-0000924 [ADA] | Raquedan v. Daproza (Order Denying February 15, 2013 Motion to Extend Time to File Reply Brief and Order Dismissing Appeal for Lack of Jurisdiction). | Circuit Court, 1st Circuit |
03/04/2013 | ICA | CAAP-12-0001052 [ADA] | State v. Mendigorin (Order Denying February 14, 2013 Motion to Remand Case for Sentence and Order Dismissing Appeal for Lack of Jurisdiction). | District Court, 1st Circuit, Honolulu Division |
03/04/2013 | S.Ct | SCPW-13-0000078 [ADA] | Tierney v. Perkins (Order Denying Petition for Writ of Mandamus Petition for Writ of Mandamus, filed 02/07/2013. Motion for Reconsideration, filed 03/18/2013. S.Ct. Order Denying Motion for Reconsideration, filed 03/21/2013 [ada]. | Original Proceeding |
03/04/2013 | S.Ct | SCPW-13-0000100 [ADA] | Grindling v. Cardoza (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 02/19/2013. | Original Proceeding |
03/04/2013 | S.Ct | SCWC-10-0000189 [ADA] | Elsenbach v. Elsenbach (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 10/17/2012 [ada], 128 Haw. 312. Petitioner's Application for Writ of Certiorari, filed 01/22/2013. | Family Court, 3rd Circuit |
03/04/2013 | S.Ct | SCWC-11-0000608 [ADA] | State v. Florence (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 11/23/2012 [ada], 128 Haw. 476 Application for Writ of Certiorari, filed 01/28/2013. | Circuit Court, 1st Circuit |
03/01/2013 | S.Ct | SCAD-12-0000414 [ADA] | Office of Disciplinary Counsel v. Ng (Order of Suspension). Request for Reconsideration, filed 03/08/2013. S.Ct. Order Denying Motion for Reconsideration, filed 03/18/2013 [ada]. | Original Proceeding |
03/01/2013 | S.Ct | SCAD-12-0000667 [ADA] | Office of Disciplinary Counsel v. Highnote (Order). S.Ct. Order, filed 09/24/2012 [ada]. | Original Proceeding |
02/28/2013 | ICA | 29669 [ADA] | State v. Reeves (s.d.o., reversed). | Circuit Court, 2nd Circuit (Criminal) | 129 Haw. 171
02/28/2013 | ICA | 30226 [ADA] | Botelho v. Atlas Recycling Centers, LLC (mop., vacated and remanded). | Labor and Industrial Relations Appeals Board (Attorney Fees) | 129 Haw. 170
02/28/2013 | ICA | 30359 [ADA] | Rigsby v. Rigsby (s.d.o., reconsideration is affirmed, court lacks jurisdiction on the remainder of the issues). | Family Court, 1st Circuit (Divorce) | 129 Haw. 171
02/28/2013 | ICA | 30480 [ADA] | Birano v. State (s.d.o., affirmed in part, vacated in part and remanded). | Circuit Court, 1st Circuit (Criminal) | 129 Haw. 171
02/28/2013 | ICA | CAAP-11-0001100 [ADA] | Kanahele v. Brodbeck (mem.op., vacated and remanded). | Circuit Court, 3rd Circuit (Quiet Title) | 129 Haw. 170
02/28/2013 | ICA | CAAP-12-0000468 [ADA] | Stanton v. State (s.d.o., vacated in part, affirmed in part and remanded). ICA Order of Correction, filed 04/26/2013 [ada]. | Circuit Court, 1st Circuit | 129 Haw. 171
02/28/2013 | ICA | CAAP-12-0000637 [ADA] | O'Grady v. State, Department of Transportation (Order Dismissing Appeal for Lack of Appellate Jurisdiction). | Circuit Court, 3rd Circuit |
02/28/2013 | ICA | CAAP-12-0000660 [ADA] | State v. American Lending Alliance, Inc. (Order Granting the February 19, 2013 Motion for Voluntary Dismissal of Appeal with Prejudice). | Circuit Court, 1st Circuit |
02/27/2013 | S.Ct | SCWC-12-0000676 [ADA] | Sherrill v. Pico (Order Rejecting Application for Writ of Certiorari). ICA Order Dismissing Appeal Pursuant to HRAP Rule 11(c)(2), filed 11/26/2012 [ada]. ICA Order Denying Petitioner-Appellant's November 26, 2012 Motion for Reconsideration, filed 11/29/2012 [ada]. Application for Writ of Certiorari, filed 01/18/2013. | Circuit Court, 1st Circuit |
02/27/2013 | ICA | 29352 [ADA] | State v. Hawaii Government Employees Association, AFSCME Local No. 152, AFL-CIO (mem.op., affirmed). Concurring and Dissenting Opinion by J. Nakamura [ada]. ICA Order of Correction, filed 03/21/2013 [ada]. | Circuit Court, 1st Circuit (Civil) | 129 Haw. 170
02/27/2013 | ICA | 30068 [ADA] | Holualoa Aloha, LLC v. Anekona Aloha, LLC (s.d.o., affirmed). | Circuit Court, 1st Circuit (Civil) | 129 Haw. 106
02/27/2013 | ICA | 30358 [ADA] | Collins v. Wassell (s.d.o., void for lack of jurisdiction). | Family Court, 3rd Circuit (Attorneys' Fees and Costs) | 129 Haw. 171
02/27/2013 | S.Ct | SCWC-11-0000107 [ADA] | State v. Simon (Order Rejecting Application for Writ of Certiorari). Amended Dissenting Opinion by J. Acoba [ada]. J. Pollack Concurring in Result Recommended by the Dissent. ICA s.d.o., filed 10/26/2012 [ada], 128 Haw. 313. Application for Writ of Certiorari, filed 01/23/2013. | District Court, 3rd Circuit, North and South Kona Division |
02/26/2013 | ICA | 29945 [ADA] | Tretsven v. Tretsven (s.d.o., vacated and remanded). | Family Court, 1st Circuit (Divorce) | 129 Haw. 106
02/26/2013 | ICA | CAAP-11-0000506 [ADA] | State v. Pablo (s.d.o., affirmed). | Circuit Court,1st Circuit (Criminal) | 129 Haw. 171
02/26/2013 | ICA | CAAP-11-0000765 [ADA] | State v. Lockey (s.d.o., vacated, remanded and dismiss without prejudice). Dissenting Opinion by J. Nakamura [ada]. | Family Court, 1st Circuit (Harassment) | 129 Haw. 106
02/26/2013 | S.Ct | SCWC-30734 [ADA] | State v. Kahanaoi (Order Rejecting Application for Writ of Certiorari). ICA mem.op., filed 10/22/2012 [ada]. Application for Writ of Certiorari, filed 01/15/2013. | Circuit Court, 1st Circuit |
02/25/2013 | S.Ct | SCAP-12-0000392 [ADA] | State v. Bortel (mem.op., vacated, remanded and dismissed). | District Court, 1st Circuit (Traffic) | 129 Haw. 153
02/25/2013 | S.Ct | SCPW-13-0000054 [ADA] | Hayakawa v. State (Order Denying without Prejudice Petition for Writ of Habeas Corpus). | Original Proceeding |
02/22/2013 | S.Ct | SCAD-13-0000016 [ADA] | Disciplinary Board of the Hawaii Supreme Court v. Kaneshiro (Order to Transfer to Inactive Status). | Original Proceeding |
02/22/2013 | S.Ct | SCPW-13-0000053 [ADA] | Hawaii State Teachers Association and Hawaii Labor Relations Board (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 01/28/2013. | Original Proceeding |
02/22/2013 | ICA | 29553 [ADA] | Nakajima v. Nakajima (Order Dismissing Appeal). Dissenting Opinion by J. Nakamura [ada]. Plaintiff/Cross-Defendant-Appellant's Motion for Reconsideration of the Court's Order Dismissing Appeal, filed 03/04/2013. ICA Order Denying "Plaintiff/Cross-Defendant-Appellant's Motion for Reconsideration of the Court's Order Dismissing Appeal filed on February 22, 2013, filed 03/08/2013 [ada]. C.J. Nakamura Dissenting. Application for Writ of Certiorari, filed 04/09/2013. S.Ct. Order Accepting Application for Writ of Certiorari, filed 05/21/2013 [ada]. | Family Court, 2nd Circuit |
02/22/2013 | ICA | 29824 [ADA] | Picardy v. Sky River Management, LLC (s.d.o., affirmed). Consolidated with No. 29825. | Circuit Court, 1st Circuit (Arbitration) | 129 Haw. 106
02/22/2013 | ICA | CAAP-12-0000424 [ADA] | Gao v. Hawaii Labor Relations Board (s.d.o., affirmed). | Circuit Court, 1st Circuit (Civil) | 129 Haw. 106
02/21/2013 | S.Ct | SCWC-30205 [ADA] | State v. Acker (Order Accepting Application for Writ of Certiorari). ICA mem.op., filed 10/12/2012 [ada], 128 Haw. 497. Application for Writ of Certiorari, filed 01/07/2013. | Circuit Court, 1st Circuit |
02/21/2013 | S.Ct | SCWC-11-0000702 [ADA] | State v. Spearman. ICA s.d.o., filed 06/27/2012 [ada], 127 Haw. 414. Petitioner-Defendant-Appellant Sarah V.P. Spearman's Petition for Certiorari, filed 09/24/2012. S.Ct. Order Accepting Application for Writ of Certiorari, filed 11/08/2012 [ada]. Petitioner-Defendant-Appellant Sarah V.P. Spearman's Motion for Reconsideration, filed 03/01/2013. S.Ct. Order Denying Motion for Reconsideration, filed 03/08/2013 [ada], 129 Haw. 163. | District Court, 1st Circuit | 129 Haw. 146
02/21/2013 | S.Ct | SCPW-13-0000095 [ADA] | Tierney v. State (Order Denying Petition for Writ of Mandamus). Motion for Reconsideration, filed 03/04/2013. S.Ct. Order Denying Motion for Reconsideration, filed 03/13/2013 [ada]. Motion for Reconsideration, filed 05/08/2013. S.Ct. Order Denying Motion for Reconsideration, filed 05/20/2013 [ada]. | Original Proceeding |
02/21/2013 | ICA | 29570 [ADA] | Martin v. C. Brewer and Company, Ltd. (s.d.o., affirmed). Plaintiff-Appellant/Cross-Appellee Gail Martin's Motion for Reconsideration, filed 03/04/2013. ICA Order Denying Motion for Reconsideration, filed 03/20/2013 [ada]. | Circuit Court, 3rd Circuit (Motor Vehicle Accident) | 129 Haw. 106
02/21/2013 | ICA | 29779 [ADA] | Scroggin v. Mandarin Oriental Management (USA), Inc. (s.d.o., affirmed in part, vacated in part and remanded). | Circuit Court, 1st Circuit (Civil) | 129 Haw. 106
02/21/2013 | ICA | 29838 [ADA] | Naito v. Naito (s.d.o., affirmed). Motion to Reconsider Summary Disposition Order, filed 02/21/2013. ICA Order Denying Motion for Reconsideration, filed 03/08/2013 [ada]. | Circuit Court, 1st Circuit (Civil) | 129 Haw. 106
02/21/2013 | ICA | 30261 [ADA] | Dennis v. Dennis (s.d.o., affirmed). | Family Court, 1st Circuit (Attorney's Fees and Costs) | 129 Haw. 106
02/21/2013 | ICA | 30275 [ADA] | State v. Miecho (s.d.o., reversed). | District Court, 1st Circuit (Traffic) | 129 Haw. 171
02/21/2013 | ICA | 30550 [ADA] | In re Tax Appeal of Narmore (s.d.o., affirmed). | Tax Appeal Court | 129 Haw. 106
02/21/2013 | ICA | 30644 [ADA] | Lahaina Fashions, Inc. v. Bank of Hawaii. Appellant's Motion for Reconsideration, filed 03/04/2013. ICA Order Denying Motion for Reconsideration, filed 03/13/2013 [ada]. | Circuit Court, 2nd Circuit | 129 Haw. 250
02/21/2013 | ICA | CAAP-11-0000891 [ADA] | State v. Tunley (s.d.o., affirmed). Application for Writ of Certiorari, filed 03/24/2013. | Family Court, 1st Circuit (Resentencing) | 129 Haw. 106
02/21/2013 | ICA | CAAP-11-0000929 [ADA] | State v. Wicks (mem.op., vacated and remanded). Consolidated with No. CAAP-11-0000930. | Circuit Court, 1st Circuit (Criminal) | 129 Haw. 170
02/21/2013 | ICA | CAAP-12-0000001 [ADA] | Decosta v. Carlson (mem.op., affirmed). | Family Court, 1st Circuit (Divorce) | 129 Haw. 170
02/20/2013 | ICA | CAAP-12-0000519 [ADA] | Frye v. Reyes (Order Granting Defendant-Appellant's February 7. 2013 Motiont o Withdraw Appeal). | Circuit Court, 2nd Circuit |
02/20/2013 | ICA | CAAP-12-0000648 [ADA] | In re Estate of Camacho (Order Dismissing Appeal for Lack of Jurisdiction). | Circuit Court, 1st Circuit |
02/20/2013 | ICA | CAAP-12-0000668 [ADA] | State v. Joy (Order Denying the February 15, 2013 Motion for Reconsideration of Appeal and to Set Aside Dismissal). ICA Order Dismissing Appeal Pursuant to HRAP Rule 30, filed 02/06/2013 [ada]. Motion for Reconsideration of Appeal and to Set Aside Dismissal, filed 02/15/2013 | Circuit Court, 1st Circuit |
02/20/2013 | ICA | CAAP-12-0000880 [ADA] | State v. Smith (Order Granting Appellant State of Hawaii's February 7, 2013 Motion to Dismiss Appeal). | Circuit Court, 5th Circuit |
02/20/2013 | S.Ct | SCWC-11-0000458 [ADA] | State v. Farren (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 11/15/2012 [ada], 128 Haw. 475. Application of Writ of Certiorari, filed 01/22/2013. | Family Court, 1st Circuit |
02/19/2013 | S.Ct | SCPW-13-0001127 [ADA] | State v. Slavick (Order Denying Motion for Reconsideration). S.Ct. Order Denying without Prejudice Motion for Habeas Corpus, filed 01/23/2013 [ada]. Motion for Reconsideration, filed 02/07/2013. Motion for Reconsideration, filed 03/27/2013. S.Ct. Order Dismissing Motion for Reconsideration, filed 04/03/2013 [ada]. | Original Proceeding |
02/19/2013 | S.Ct | SCPW-12-0001116 [ADA] | Tierney v. Sakai (Order Denying Motion for Reconsideration). Petition for Writ of Mandamus, filed 10/02/2012. S.Ct. Order Denying without Petition for Writ of Mandamus, filed 11/01/2012 [ada]. Petition for Writ of Mandamus, filed 12/27/2012. S.Ct. Order Denying Petition for Writ of Mandamus, filed 01/24/2013 [ada]. Motion for Reconsideration, filed 02/07/2013. Petition for Writ of Mandamus for Emergency Medical and Dental Treatment, filed 02/08/2013. S.Ct. Order Denying Petition for Writ of Mandamus, filed 03/13/2013 [ada]. Motion for Reconsideration, filed 03/22/2013. S.Ct. Order Denying Motion for Reconsideration, filed 04/01/2013 [ada]. | Original Proceeding |
02/19/2013 | S.Ct | SCPW-12-0000831 [ADA] | Tierney v. Sakai (Order Denying Motion for Reconsideration). Petition for Writ of Mandamus, filed 10/02/2012. S.Ct. Order Denying without Prejudice Petition for Writ of Mandamus, filed 11/01/2012 [ada]. Petition, filed 12/27/2012. S.Ct. Order Denying Petition for Writ of Mandamus, filed 01/24/2013 [ada]. Motion for Reconsideration, filed 02/07/2013. Petition for Writ of Mandamus, filed 02/08/2013. S.Ct. Order Denying Motion for Reconsideration, filed 02/19/2013 [ada]. S.Ct. Order Denying Petition for Writ of Mandamus, filed 03/13/2013 [ada]. Motion for Reconsideration, filed 03/22/2013. S.Ct. Order Denying Motion for Reconsideration, filed 04/01/2013 [ada]. | Original Proceeding |
02/19/2013 | S.Ct | SCPW-13-0000001 [ADA] | Tierney v. Liu (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 01/04/2013. Motion for Reconsideration, filed 02/19/2013. S.Ct. Order Denying Motion for Reconsideration, filed 03/08/2013 [ada]. | Original Proceeding |
02/19/2013 | S.Ct | SCPW-13-0000019 [ADA] | Simeona v. Abercrombie (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 01/10/2013. | Original Proceeding |
02/15/2013 | ICA | CAAP-10-0000084 [ADA] | McCully Associates v. Marn (s.d.o., affirmed). | Circuit Court, 1st Circuit (Civil) | 129 Haw. 106
02/15/2013 | ICA | CAAP-11-0000586 [ADA] | State v. Ungounga (s.d.o., affirmed). Application for Writ of Certiorari, filed 04/12/2013. S.Ct. Order Rejecting Application for Writ of Certiorari, filed 05/23/2013 [ada]. | Circuit Court, 1st Circuit | 129 Haw. 106
02/15/2013 | S.Ct | SCAD-12-0000405 [ADA] | Office of Disciplinary Counsel v. Wooten (Order of Suspension). | Original Proceeding |
02/15/2013 | S.Ct | SCAD-12-0000950 [ADA] | Office of Disciplinary Counsel v. Bertelmann (Order of Suspension). | Original Proceeding |
02/15/2013 | S.Ct | SCWC-11-0000488 [ADA] | County of Hawaii v. Lui (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 10/30/2012 [ada], 128 Haw. 475. Application for Writ of Certiorari, filed 01/03/2013. S.Ct. Order Rejecting Application for Writ of Certiorari, filed 01/24/2012 [ada]. S.Ct. Order Vacating Certiorari, filed 02/13/2013 [ada]. | District Court, 3rd Circuit |
02/14/2013 | S.Ct | SCAD-12-0000376 [ADA] | Office of Disciplinary Counsel v. Fernandez (Order of Disbarment). | Original Proceeding |
02/14/2013 | S.Ct | SCPW-13-0000050 [ADA] | Ruh v. Intermediate Court of Appeals (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 01/28/2013. | Original Proceeding. |
02/14/2013 | ICA | 29550 [ADA] | State v. Calara (s.d.o., affirmed). Application for Writ of Certiorari, filed 05/16/2013. | Circuit Court, 1st Circuit (Sexual Assault) | 129 Haw. 106
02/14/2013 | ICA | 29702 [ADA] | Wahi Ho‘omalu Limited Partnership v. Maio (s.d.o., affirmed). | Circuit Court, 2nd Circuit (Civil) | 129 Haw. 106
02/14/2013 | ICA | 29946 [ADA] | State v Rego (s.d.o., reversed). ICA Order of Correction, filed 04/11/2013 [ada]. | Family Court, 1st Circuit (Harassment) | 129 Haw. 106
02/14/2013 | ICA | CAAP-11-0001107 [ADA] | In re Hawaii State Teachers Association (s.d.o., affirmed). Consolidated with No. CAAP-12-0000047. | Circuit Court, 1st Circuit (Labor Dispute) | 129 Haw. 105
02/14/2013 | S.Ct | SCWC-11-0000814 [ADA] | State v. Han (Order Accepting Application for Writ of Certiorari). ICA s.d.o., filed 09/12/2012 [ada], 128 Haw. 198. Application for Writ of Certiorari, filed 12/31/2012. | Family Court, 1st Circuit |
02/14/2013 | ICA | CAAP-11-0000909 [ADA] | Accredited Home Lenders, Inc. v. Vaka (Order Dismissing Appeal Pursuant to HRAP Rule 30). | Circuit Court, 2nd Circuit |
02/13/2013 | ICA | CAAP-11-0000785 [ADA] | State v. Attaguile (s.d.o., affirmed). Application for Writ of Certiorari, filed 04/12/2013. S.Ct. Order Rejecting Application for Writ of Certiorari, filed 05/10/2013 [ada]. | District Court, 2nd Circuit, Wailuku Division (Traffic) | 129 Haw. 105
02/13/2013 | S.Ct | SCWC-11-0000488 [ADA] | County of Hawaii v. Lui (Order Vacating Certiorari). ICA s.d.o., filed 10/30/2013 [ada], 128 Haw. 475. Application for Writ of Certiorari, filed 01/03/2013. S.Ct. Order Rejecting Application for Writ of Certiorari, filed 01/24/2012 [ada]. S.Ct. Order Rejecting Application for Writ of Certiorari, filed 02/15/2013 [ada]. | District Court, 3rd Circuit |
02/12/2013 | S.Ct | SCWC-11-0000791 [ADA] | Fukumoto v. State (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 11/21/2012 [ada], 128 Haw. 476 . Application for Writ of Certiorari, filed 12/31/2012. | Circuit Court, 2nd Circuit |
02/12/2013 | ICA | 29448 [ADA] | In re Mann Family Litigation (s.d.o., affirmed in part, vacated in part and remanded). | Circuit Court, 1st Circuit (Awarding Fees and Costs) | 129 Haw. 105
02/12/2013 | ICA | 29486 [ADA] | McCully Associates v. Ten Grand Associates (s.d.o., affirmed). | Circuit Court, 1st Circuit (Civil) | 129 Haw. 105
02/12/2013 | ICA | CAAP-12-0000719 [ADA] | State v. Tanaka (Order Dismissing Appeal Pursuant to HRAP Rule 30). | District Court, 1st Circuit |
02/11/2013 | ICA | 29927 [ADA] | Yukimura v. Yukimura (Order Denying Appellant's Motion for Reconsideration). ICA s.d.o., filed 01/22/2013 [ada], 129 Haw. 29. Appellant's Motion for Reconsideration, filed 02/01/2013. Application for Writ of Certiorari, filed 04/15/2013. | Family Court, 5th Circuit |
02/11/2013 | ICA | CAAP-12-0000360 [ADA] | Chen v. Lu (s.d.o., affirmed). Application for Writ of Certiorari, filed 05/09/2013. | Family Court, 1st Circuit (Custody) | 129 Haw. 105
02/11/2013 | ICA | CAAP-11-0000654 [ADA] | State v. Beaver (s.d.o., affirmed). Application for Writ of Certiorari, filed 05/06/2013. | Family Court, 3rd Circuit (Persistent Nonsupport) | 129 Haw. 105
02/11/2013 | ICA | CAAP-12-0000390 [ADA] | In re AI and AK (s.d.o., affirmed). | Family Court, 1st Circuit (Termination of Parental Rights) | 129 Haw. 105
02/11/2013 | S.Ct | SCAD-12-0001113 [ADA] | Office of Disciplinary Counsel v. Nishioka (Order Allowing Resignation in Lieu of Discipline). | Original Proceeding |
02/11/2013 | S.Ct | SCWC-11-0000008 [ADA] | State v. Hoke IV (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 009/25/2012 [ada]. Application for Writ of Certiorari, filed 12/28/2012. | District Court, 3rd Circuit |
02/11/2013 | S.Ct | SCWC-11-000024 [ADA] | State v. Hoke IV (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 09/25/2012 [ada]. Application for Writ of Certiorari, filed 12/28/2012. | District Court, 3rd Circuit |
02/11/2013 | S.Ct | SCWC-11-0000813 [ADA] | State v. Kanaka‘ole (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 09/25/2012 [ada]. Application for Writ of Certiorari, filed 12/28/2012. | Family Court, 3rd Circuit |
02/08/2013 | ICA | 30329 [ADA] | Perry v. Perez-Wendt. | Circuit Court, 5th Circuit | 129 Haw. 95
02/06/2013 | S.Ct | SCPW-13-0000021 [ADA] | Grandinetti v. Bobby Ross Group, Inc. (BRG) (Order Denying Petition for Writ of Habeas Corpus and Writ of Mandamus). | Original Proceeding |
02/06/2013 | ICA | CAAP-11-0000369 [ADA] | Plauche v. Plauche (Order Denying Motion for Reconsideration of Summary Disposition Order filed January 24, 2013). ICA s.d.o., filed 01/24/2013 [ada], 129 Haw. 29. Plaintiff-Appellant Jeffrey J. Plauche's Motion for Reconsideration of Summary Disposition Order filed on January 24, 2013, filed 02/01/2013. Application for Writ of Certiorari, filed 03/24/2013. S. Ct. Order Dismissing Application for Writ of Certiorari, filed 03/28/2013 [ada]. Application for Writ of Certiorari, filed 04/29/2013. | Family Court, 2nd Circuit Court |
02/06/2013 | ICA | CAAP-12-0000668 [ADA] | State v. Joy (Order Dismissing Appeal Pursuant to HRAP Rule 30). Motion for Reconsideration of Appeal and to Set Aside Dismissal, filed 02/15/2013. ICA Order Denying the February 15, 2013 Motion for Reconsideration of Appeal and to Set Aside Dismissal, filed 02/20/2013 [ada]. | Circuit Court, 1st Circuit |
02/06/2013 | ICA | CAAP-12-000739 [ADA] | In re Application of Guardian Trust Company, Limited to Register and Confirm Title to Land Situated at Waikiki, Honolulu, City and County of Hawaii, State of Hawaii v. Marn (Order Dismissing Appeals Pursuant to HRAP Rule 30). Consolidated with No. CAAP-12-0000740. | Land Court |
02/06/2013 | ICA | CAAP-12-0000810 [ADA] | Franks v. Franks (Order Granting Defendant-Appellant's January 31, 2013 Motion to Close Case). | Family Court, 3rd Circuit |
02/06/2013 | S.Ct | SCWC-11-0000338 [ADA] | State v. Gomez-Lobato (Order Granting Application for Writ of Certiorari). ICA s.d.o., filed 10/25/2012 [ada], 128 Haw. 312. Application for Writ of Certiorari, filed 12/21/2012. | Family Court, 3rd Circuit |
02/05/2013 | ICA | CAAP-12-0001038 [ADA] | State v. Howard (Order Approving the January 21, 2013 Stipulation of the Parties for Dismissal of Appeal). | District Court, 5th Circuit |
02/05/2013 | S.Ct | SCAD-12-0001034 [ADA] | Office of Diciplinary Counsel v. Agard (Order of Suspension). | Original Proceeding |
02/01/2013 | ICA | CAAP-12-0000381 [ADA] | State v. Hunt (Order Approving the Stipulation for Dismissal of Appeal filed on January 22, 2013). | District Court, 3rd Circuit |
01/31/2013 | ICA | CAAP-11-0000166 [ADA] | Karpeles Manuscript Library v. Duarte. ICA Order Granting Appellants' Motion for Publication of the Court's December 20, 2012 Memorandum Opinion, filed 01/28/2013 [ada]. ICA memo.op., filed 12/20/2012. | Circuit Court, 5th Circuit | 129 Haw. 90
01/31/2013 | ICA | CAAP-11-0000393 [ADA] | State v. Kong. Application for Writ of Certiorari, filed 04/29/2013. | Circuit Court, 2nd Circuit | 129 Haw. 135
01/31/2013 | ICA | 29652 [ADA] | Kam Center Specialty Corporation v. LWC IV Corporation (memo.op., reversed and affirmed). Application for Writ of Certiorari, filed 04/12/2013. | Circuit Court, 1st Circuit (Summary Possession) |
01/31/2013 | ICA | 29727 [ADA] | In re Thomas H. Gentry Revocable Trust (mem.op., affirmed). Consolidated with No. 29728. | Circuit Court, 1st Circuit (Trust) |
01/31/2013 | ICA | 29851 [ADA] | Abadilla v. Iwata (mem.op., vacated and remanded). ICA Order of Correction, filed 03/15/2013 [ada]. Petitioner-Appellee-Defendant Sanford Iwata's Application for Writ of Certiorari, filed 04/12/2013. | Circuit Court, 3rd Circuit (Damages) |
01/31/2013 | ICA | 30123 [ADA] | Avelo Mortgage, LLC v. Segundo (s.d.o., affirmed). ICA Order of Correction, filed 03/14/2013 [ada]. ICA Amended Order of Correction, filed 03/14/2013 [ada]. | Circuit Court, 2nd Circuit (Writ of Ejectment) | 129 Haw. 105
01/30/2013 | S.Ct | SCPW-12-0000978 [ADA] | Tierney v. Sheriff's Division, Department of Public Safety (Order Denying Motion for Reconsideration). S.Ct. Order Denying Petition for Writ of Mandamus, filed 01/04/2013 [ada]. Petition for Writ of Mandamus, filed 11/02/2012. Motion for Reconsideration, filed 01/24/2013. | Original Proceeding |
01/30/2013 | ICA | 28805 [ADA] | Feddy Nobriga Enterprises, Inc. v. State, Department of Hawaiian Home Lands. | Circuit Court, 3rd Circuit | 129 Haw. 123
01/30/2013 | ICA | 30564 [ADA] | Heinzman v. Cendant Corporation (s.d.o., affirmed). | Labor and Industrial Relations Appeals Board (Workers Compensation) | 129 Haw. 105
01/30/2013 | ICA | CAAP-11-0000466 [ADA] | Felipe v. City and County of Honolulu, Honolulu Emergency Sevices Department (s.d.o.,vacated and remanded). | Labor and Industrial Relations Appeals Board (Attorney's Fees) | 129 Haw. 105
01/30/2013 | ICA | CAAP-11-0000581 [ADA] | State v. Helsen (s.d.o., reversed). | District Court, 2nd Circuit, Lahaina Division (Criminal Trespass) | 129 Haw. 105
01/30/2013 | ICA | CAAP-11-0001027 [ADA] | State v. Goo-Vidinha (mem.op., vacated and remanded). | District Court, 1st Circuit (Assault) |
01/30/2013 | S.Ct | SCAD-12-0000879 [ADA] | Office of Disciplinary Counsel v. Furusho (Order). | Original Proceeding |
01/29/2013 | ICA | CAAP-11-0000998 [ADA] | Association of Apartment Owners of the Waikoloa Beach Villas v. Sunstone Waikoloa, LLC. Application of Writ of Certiorari filed 03/28/2013. S.Ct. Order Accepting Application for Writ of Certiorari, filed 05/08/2013 [ada]. | Circuit Court, 3rd Circuit | 129 Haw. 117
01/29/2013 | S.Ct | SCWC-11-0000081 [ADA] | State v. Lui (Order Rejecting Application for Writ of Certiorari). Dissenting Opinion by J. Pollack, filed 01/29/2013 [ada]. ICA mem.op., filed 10/18/2012 [ada], 128 Haw. 497. Application for Writ of Certiorari,, filed 12/17/2012. | District Court, 3rd Circuit |
01/29/2013 | S.Ct | SCWC-11-0000749 [ADA] | State v. Hart (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 09/26/2012 [ada]. Application for Writ of Certiorari, filed 12/24/2012. | Family Court, 3rd Circuit |
01/28/2013 | ICA | CAAP-11-0000166 [ADA] | Karpeles Manuscript Library v. Duarte (Order Granting Appellants' Motion for Publication of the Court's December 20, 2012 Memorandum Opinion). ICA memo.op., filed 12/20/2012. ICA Opinion, filed 01/31/2013 [ada], 129 Haw. 90. | Circuit Court, 5th Circuit |
01/28/2013 | ICA | CAAP-12-0000054 [ADA] | Fratinardo v. The Employees' Retirement System of the State of Hawaii. | Circuit Court, 1st Circuit | 129 Haw. 107
01/28/2013 | ICA | CAAP-12-0001031 [ADA] | Hart v. Ticor Title Insurance Company (Order Approving Stipulation to Dismiss Appeal). | District Court, 1st Circuit |
01/28/2013 | S.Ct | SCWC-10-0000188 [ADA] | County of Hawaii v. UNIDEV, LLC. (Order Accepting Application for Writ of Certiorari). ICA Opinion, filed 08/31/2012 [ada], 128 Haw. 378. Consolidated with No. CAAP-11-0000019. Application for Writ of Certiorari, filed 12/17/2012. S.Ct. Opinion, filed 05/22/2013 [ada]. | Circuit Court, 3rd Circuit |
01/28/2013 | S.Ct | SCPW-13-0001153 [ADA] | Tumale v. Taguma (Order Denying Petition for Writ of Mandamus). | Original Proceeding |
01/25/2013 | ICA | CAAP-11-0001064 [ADA] | Hoku Lele, LLC v. City and County of Honolulu. | Circuit Court, 1st Circuit | 129 Haw. 164
01/25/2013 | ICA | 28948 [ADA] | Pacific Lightnet, Inc. v. Time Warner Telecom, Inc. (mem.op., affirmed in part and vacated in part). Consolidated with No. 29105. Petitioner Wavecom Solutions Corporation's Application for Writ of Certiorari, filed 04/22/2013. | Circuit Court, 1st Circuit (Civil) |
01/25/2013 | ICA | 30648 [ADA] | State v. Gray (mem.op., vacated and remanded). | Family Court, 1st Circuit (Criminal Contempt) |
01/25/2013 | ICA | CAAP-11-0000604 [ADA] | State v. Gonsalves (mem.op., vacated and remanded). | Circuit Court, 5th Circuit (Criminal) |
01/25/2013 | ICA | CAAP-11-0000823 [ADA] | Kauai Community Federal Credit Union v. Pia (Order Denying Appellant's Motion for Reconsideration of Summary Disposition Order). ICA s.d.o., filed 01/07/2013 [ada], 128 Haw. 499. Motion for Reconsideration, filed 01/17/2013. | District Court, 5th Circuit (Writ of Possession) |
01/25/2013 | ICA | 29291 [ADA] | Kaneshiro v. Administrative Director of the Courts, State of Hawaii (Order of Correction). ICA s.d.o., filed 12/19/2012 [ada], 128 Haw. 478. | District Court, 1st Circuit |
01/25/2013 | S.Ct | SCWC-30082 [ADA] | Ralston v. Yim. ICA Opinion, filed 05/31/2012. ICA Order of Amendment, filed 06/28/2012 [ada]. ICA Amended Opinion, filed 06/28/2012 [ada], 128 Haw. 42. Defendant-Appellee Errol Y.W. Yim, D.D.S.'S Application for Writ of Certiorari, filed 09/21/2012. S.Ct. Order Accepting Application for Writ of Certiorari, filed 10/30/2012 [ada]. | Circuit Court, 1st Circuit | 129 Haw. 46
01/25/2013 | S.Ct | SCWC-11-0000097 [ADA] | State v. Woodhall (Order Accepting Application for Writ of Certiorari). ICA s.d.o., filed 09/25/2012 [ada]. Application for Writ of Certiorari, filed 12/18/2012. | District Court, 3rd Circuit, North and South Kona Division (Promoting drugs) |
01/24/2013 | ICA | CAAP-11-0000367 [ADA] | State v. Dela Cruz (s.d.o., vacated and remanded). Application for Writ of Certiorari, filed 04/14/2013. | District Court, 1st Circuit, Waianae Division (Criminal) | 129 Haw. 29
01/24/2013 | ICA | CAAP-11-0000369 [ADA] | Plauche v. Plauche (s.d.o., affirmed). Plaintiff-Appellant Jeffrey J. Plauche's Motion for Reconsideration of Summary Disposition Order filed on January 24, 2013, filed 02/01/2013. ICA Order Denying Motion for Reconsideration of Summary Disposition Order filed on January 24, 2013, filed 02/06/2013 [ada]. Application for Writ of Certiorari, filed 03/24/2013. S. Ct. Order Dismissing Application for Writ of Certiorari, filed 03/28/2013 [ada]. Application for Writ of Certiorari, filed 04/29/2013. | Family Court, 2nd Circuit (Divorce) | 129 Haw. 29
01/24/2013 | S.Ct | SCPW-12-0000831 [ADA] | Tierney v. Sakai (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 10/02/2012. S.Ct. Order Denying Without Prejudice Petition for Writ of Mandamus, filed 11/01/2012 [ada]. Petition, filed 12/27/2012. Motion for Reconsideration, filed 02/07/2013. Petition for Writ of Mandamus for Emergency Medical and Dental Treatment, filed 02/08/2013. S.Ct. Order Denying Motion for Reconsideration, filed 02/19/2013 [ada]. S.Ct. Order Denying Petition for Writ of Mandamus, filed 03/13/2013 [ada]. Motion for Reconsideration, filed 03/22/2013. S.Ct. Order Denying Motion for Reconsideration, filed 04/01/2013 [ada]. | Original Proceeding |
01/24/2013 | S.Ct | SCPW-12-0001033 [ADA] | Hester v. Horowitz (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 11/21/2012. | Original Proceeding |
01/24/2013 | S.Ct | SCPW-12-0001057 [ADA] | Sakuma v. Ayabe (Order Denying without Prejudice Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 11/30/2012. | Original Proceeding |
01/24/2013 | S.Ct | SCPW-12-0001116 [ADA] | Tierney v. Sakai (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 12/27/2012. Motion for Reconsideration, filed 02/07/2013. S.Ct. Order Denying Motion for Reconsideration, filed 02/19/2013 [ada]. | Original Proceeding |
01/24/2013 | S.Ct | SCWC-29581 [ADA] | State v. Bruce (Order rejecting application for Writ of Certiorari). ICA s.d.o., filed 10/31/2012 [ada]. Application for Writ of Certiorari, filed 12/28/2012. | Circuit Court, 5th Circuit |
01/24/2013 | S.Ct | SCWC-11-0000488 [ADA] | County of Hawai'i v. Lui (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 10/30/2012 [ada], 128 Haw. 475. Application for Writ of Certiorari, filed 01/03/2013. S.Ct. Order Vacating Certiorari, filed 02/13/2013 [ada]. S.Ct. Order Rejecting Application for Writ of Certiorari, filed 02/15/2013 [ada]. | District Court, 3rd Circuit |
01/23/2013 | ICA | CAAP-11-0000462 [ADA] | McAulton v. Cambridge Management, Inc. (s.d.o., affirmed). | Circuit Court, 1st Circuit (Civil) |
01/23/2013 | ICA | 30293 [ADA] | Hester v. Horowitz (Order Dismissing Appeal for Lack of Appellate Jurisdiction). | Circuit Court, 3rd Circuit |
01/23/2013 | ICA | 30347 [ADA] | State v. Patron (s.d.o., affirmed). | District Court, 2nd Circuit, Wailuku Division (Assault) | 129 Haw. 29
01/23/2013 | ICA | 30690 [ADA] | State v. Spears (s.d.o., dismissed). Consolidated with Nos. 30529 and 30530. | Circuit Court, 2nd Circuit (Criminal) | 129 Haw. 29
01/23/2013 | S.Ct | SCAD-12-0000822 [ADA] | Office of Disciplinary Counsel v. Eliason (Order of Suspension). S.Ct. Order of Reinstatement, filed 04/30/2013 [ada]. | Original Proceeding |
01/23/2013 | S.Ct | SCPW-12-0001066 [ADA] | Akui v. Sakai (Order) | Original Proceeding |
01/23/2013 | S.Ct | SCPW-12-0001124 [ADA] | State v. Slavick (Order Denying Petition for Writ of Prohibition). Motion for Reconsideration, filed 03/27/2013. S.Ct. Order Dismissing Motion for Reconsideration, filed 04/03/2013 [ada]. | Original Proceeding |
01/23/2013 | S.Ct | SCPW-12-0001126 [ADA] | In re Hanohano (Order). | Original Proceeding |
01/23/2013 | S.Ct | SCPW-13-0001127 [ADA] | State v. Slavick (Order Denying without Prejudice Motion for Habeas Corpus). Motion for Reconsideration, filed 02/07/2013. S.Ct. Order Denying Motion for Reconsideration, filed 02/19/2013 [ada]. Motion for Reconsideration, filed 03/27/2013. S.Ct. Order Dismissing Motion for Reconsideration, filed 04/03/2013 [ada]. | Original Proceeding |
01/22/2013 | ICA | 29927 [ADA] | Yukimura v. Yukimura (s.d.o., affirmed). Appellant's Motion for Reconsideration, filed 02/01/2013. ICA Order Denying Appellant's Motion for Reconsideration, filed 02/11/2013 [ada]. Application for Writ of Certiorari, filed 04/15/2013. | Family Court, 5th Circuit (Divorce) | 129 Haw. 29
01/22/2013 | ICA | CAAP-11-0000642 [ADA] | State v. Kin Choy (s.d.o., affirmed). | Circuit Court, 2nd Circuit (Assault) | 129 Haw. 29
01/22/2013 | ICA | 29129 [ADA] | Yamamoto v. Yamamoto (s.d.o., affirmed). Consolidated with No. 29917. | Family Court, 1st Circuit (Family) | 129 Haw. 29
01/18/2013 | ICA | 29124 [ADA] | Jarrell v. Jarrell (s.d.o., affirmed). | Family Court, 1st Circuit (Divorce) | 129 Haw. 29
01/18/2013 | ICA | CAAP-11-0000064 [ADA] | State v. DeLeon (s.d.o., reversed, vacated and affirmed). Application for Writ of Certiorari, filed 04/15/2013. S.Ct. Order Accepting Application for Writ of Certiorari, filed 05/22/2013 [ada]. | Circuit Court, 1st Circuit (Criminal) | 129 Haw. 29
01/18/2013 | ICA | CAAP-12-0000617 [ADA] | Wells Fargo Bank, N.A. v. Omiya (Order Dismissing Appeal for Lack of Jurisdiction). | Circuit Court, 1st Circuit |
01/18/2013 | S.Ct | SCWC-11-0001034 [ADA] | Alvarez v. Kyo-Ya, Inc. (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 10/25/2012 [ada], 128 Haw. 475. Application for Writ of Certiorari filed by Petitioner-Appellant Emerson M.F. Jou, M.D., filed 12/20/2012. | Labor and Indsutrial Relations Appeals Board |
01/18/2013 | S.Ct | SCWC-12-0000114 [ADA] | Grindling v. State (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 10/25/2012 [ada]. Consolidated with No. CAAP-12-0000129. Motion for Certiorari, filed 11/05/2012. S.Ct. Order Dismissing Application for Writ of Certiorari, filed 11/08/2012 [ada]. Petition for Writ of Certiorari, filed 12/07/2012. | Circuit Court, 2nd Circuit |
01/17/2013 | ICA | CAAP-12-0000603 [ADA] | Swift v. Swift (Order Dismissing Appeal and Cross-Appeal for Lack of Jurisdiction). | Circuit Court, 1st Circuit |
01/16/2013 | S.Ct | SCWC-28917 [ADA] | NST Holdings Corp. v. Altres. Inc. (Order Accepting Application for Writ of Certiorari). ICA mem. op., filed 09/21/2012 [ada], 128 Haw. 310. Application for Writ of Certiorari, filed 12/03/2012. S.Ct. Order Approving Stipulation for Dismissal, filed 03/21/2013 [ada]. | Circuit Court, 1st Circuit |
01/15/2013 | S.Ct | SCWC-30587 [ADA] | Kuehu v. Gate Gourmet. Inc. (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 09/19/2012 [ada], 128 Haw. 311. Application for Writ of Certiorari, filed 12/04/2012. | Circuit Court, 1st Circuit |
01/15/2013 | S.Ct | SCWC-30573 [ADA] | Diamond v. Dubbin (Order Accepting Application for Writ of Certiorari). ICA mem.op., filed 08/31/2012 [ada], 128 Haw. 128. Application for Writ of Certiorari, filed 12/03/2012. | Circuit Court, 5th Circuit |
01/14/2013 | ICA | CAAP-11-0001080 [ADA] | Unciano v. GMAC Mortgage, LLC (Order Dismissing Appeal for Lack of Appellate Jurisdiction). | Land Court |
01/14/2013 | S.Ct | SCAD-12-0000726 [ADA] | Office of Disciplinary Counsel v. Condit (Order). | Original Proceeding |
01/14/2013 | S.Ct | SCPW-12-0001118 [ADA] | Tierney v. Matsuoka (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 12/27/2012. | Original Proceeding |
01/14/2013 | S.Ct | SCPW-12-0000979 [ADA] | Tierney v. District Court of the First Circuit, Honolulu Division, State of Hawaii (Order Denying Motion for Reconsideration). Petition for Writ of Mandamus, filed 11/02/2012. S.Ct. Order Denying Petition for Writ of Mandamus, filed 12/17/2013 [ada]. Motion for Reconsideration, filed 01/04/2013. | Original Proceeding |
01/14/2013 | S.Ct | SCPW-12-0001013 [ADA] | Tierney v. Perkins (Order Denying Motion for Reconsideration). Petition for Writ of Mandamus, filed 11/16/2012. S.Ct. Order Denying Petition for Writ of Mandamus, filed 12/17/2012 [ada]. Motion for Reconsideration, filed 01/04/2013. | Original Proceeding |
01/11/2013 | ICA | CAAP-11-0000647 [ADA] | State v. Albert (s.d.o., affirmed). Application for Writ of Certiorari, filed 04/08/2013. S.Ct. Order Rejecting Application for Writ of Certiorari, filed 05/07/2013 [ada]. | Circuit Court, 1st Circuit (Assault) | 128 Haw. 500
01/11/2013 | ICA | CAAP-12-0000992 [ADA] | First Hawaiian Bank v. McIntire (Order Granting the Motion to Dismiss filed on January 3, 2013). | Circuit Court, 2nd Circuit |
01/11/2013 | ICA | CAAP-12-0000870 [ADA] | Association of Condominium Homeowners of Tropics at Waikele v. Sakuma (Order Dismissing Appeal for Lack of Jurisdiction). Petitioner Pro Se Patsy N. Sakuma's Application for Writ of Certiorari, filed 03/15/2013. S.Ct. Order Granting Motion for Leave of Court to File Conforming Application for Writ of Certiorari, filed 04/02/2013 [ada]. S.Ct. Order Accepting Amended Application for Writ of Certiorari, filed 04/24/2013 [ada]. Dissenting Opinion by J. Nakayama [ada]. | Circuit Court, 1st Circuit |
01/10/2013 | ICA | CAAP-12-0000625 [ADA] | Oahu Publications, Inc. v. Abercrombie (Order Denying January 6, 2013 HRAP Rule 40 Motion for Reconsideration of December 27, 2012 Order Dismissing Appeal for Lack of Jurisdiction). ICA Order Dismissing Appeal for Lack of Jurisdiction, filed 12/27/2012 [ada]. Defendant Governor Abercrombie's Motion for Reconsideration of Order Dismissing Appeal for Lack of Jurisdiction filed December 27, 2012, filed 01/06/2013. | Circuit Court, 1st Circuit |
01/10/2013 | S.Ct | SCWC-30059 [ADA] | State v. Stone (Order Accepting Application for Writ of Certiorari). ICA s.d.o., filed 08/31/2012 [ada], 128 Haw. 131. Concurring and Dissenting Opinion by J. Nakamura [ada]. Application for Writ of Certiorari, filed 11/30/2012. | District Court, 2nd Circuit, Wailuku Division |
01/10/2013 | S.Ct | SCPW-12-0001016 [ADA] | Tierney v. Sakai (Order Denying Petition for Writ of Mandamus). J. Acoba Dissenting. Petition for Writ of Mandamus, filed 11/16/2012. | Original Proceeding |
01/10/2013 | S.Ct | SCPW-12-0000968 [ADA] | Suzuki v. Board of Public Accountancy (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 11/01/2012. | Original Proceeding |
01/10/2013 | S.Ct | SCWC-11-0000472 [ADA] | Knight v. State (Order Dismissing Application for Writ of Certiorari). ICA s.d.o., filed 12/07/2012 [ada], 128 Haw. 477. Application for Writ of Certiorari, filed 12/31/2012. Application for Writ of Certiorari, filed 01/28/2013. S.Ct. Order Rejecting Application for Writ of Certiorari, filed 03/13/2013 [ada]. | Circuit Court, 1st Circuit |
01/09/2013 | S.Ct | SCPR-12-0001122 [ADA] | In re Dell-Wilson (Order Granting Petition to Resign and Surrender License). | Original Proceeding |
01/09/2013 | ICA | CAAP-11-0000524 [ADA] | State v. Tapia (s.d.o., vacated and remanded). | Family Court, 1st Circuit (Abuse of a Family or Household Member) | 128 Haw. 499
01/09/2013 | ICA | CAAP-12-0000023 [ADA] | State v. Enriques (s.d.o., affirmed). | Family Court, 3rd Circuit, Kona Division (Abuse of a Family or Household Member) | 128 Haw. 499
01/08/2013 | ICA | CAAP-12-0000871 [ADA] | Grindling v. Songstad (Order Granting the January 3, 2013 Motion to Withdraw). | Circuit Court, 2nd Circuit |
01/08/2013 | ICA | 30559 [ADA] | State v. Pitts (s.d.o., affirmed). Petitioner/Defendant-Appellant Joseph Pitts' Application for Writ of Certiorari, filed 04/17/2013. S.Ct. Order Accepting Application for Writ of Certiorari and Ordering Supplemental Briefing, filed 05/15/2013 [ada]. | Circuit Court, 1st Circuit (Murder) | 128 Haw. 499
01/07/2013 | ICA | CAAP-11-0000823 [ADA] | Kauai Community Federal Credit Union v. Pia (s.d.o., affirmed). Defendant-Appellant's Motion for Reconsideration, filed 01/17/2013. ICA Order Denying Appellant's Motion for Reconsideration of Summary Disposition Order, filed 01/25/2013 [ada]. | District Court, 5th Circuit (Writ of Possession) | 128 Haw. 499
01/07/2013 | ICA | CAAP-12-0000261 [ADA] | State v. Iona (s.d.o., vacated, remanded and dismissed without prejudice). | District Court, 1st Circuit, Honolulu Division (DUI) |
01/07/2013 | S.Ct | SCWC-10-0000212 [ADA] | State v. Million (Order Dismissing Application for Writ of Certiorari). ICA s.d.o., filed 11/30/2012 [ada], 128 Haw. 477. Dissenting Opinion by J. Reifurth [ada]. Application for Writ of Certiorari, filed 12/27/2012. Application for Writ of Certiorari, filed 02/07/2013. S.Ct. Order Rejecting Application for Writ of Certiorari, filed 03/19/2013 [ada]. | Circuit Court, 3rd Circuit |
01/04/2013 | S.Ct | SCWC-11-0000089 [ADA] | State v. Kaulia (Amended Opinion of the Court by Pollack, J.). ICA s.d.o., filed 06/29/2012 [ada], 127 Haw. 414. Application for Writ of Certiorari, filed 09/04/2012. S.Ct. Order Accepting Application for Writ of Certiorari, filed 10/16/2012 [ada]. S.Ct. Order of Correction, filed 01/04/2013 [ada]. | District Court, 3rd Circuit, North and South Kona (Assault) | 128 Haw. 479
01/04/2013 | ICA | 30476 [ADA] | In re Meyer (Order Denying Defendant-Appellant's Motion for Reconsideration). ICA s.d.o., filed 10/09/2012 [ada], 128 Haw. 499. Motion for Reconsideration, filed 12/13/2012. | Labor and Industrial Relations Appeals Board |
01/04/2013 | S.Ct | SCWC-11-0000049 [ADA] | State v. Ngo. ICA s.d.o., filed 03/21/2012 [ada], 126 Haw. 414. Application for Writ of Certiorari, filed 06/02/2012. S.Ct. Order Accepting Application for Writ of Certiorari, filed 07/13/2012 [ada]. | Circuit Court, 1st Circuit (Criminal) | 129 Haw. 30
01/04/2013 | S.Ct | SCWC-11-0000089 [ADA] | State v. Kaulia (Order of Correction). ICA s.d.o., filed 06/29/2012 [ada], 127 Haw. 414. Application for Writ of Certiorari, filed 09/04/2012. S.Ct. Order Accepting Application for Writ of Certiorari, filed 10/16/2012 [ada]. S.Ct. Amended Opinion, filed 01/04/2013 [ada], 128 Haw. 479. | District Court, 3rd Circuit, North and South Kona |
01/04/2013 | S.Ct | SCPW-12-0000978 [ADA] | Tierney v. Sheriff's Division, Department of Public Safety (Order Denying Petition for Writ of Mandamus). Petition for Writ of Mandamus, filed 11/02/2012. Motion for Reconsideration, filed 01/24/2013. S.Ct. Order Denying Motion for Reconsideration, filed 01/30/2013 [ada]. | Original Proceeding |
01/03/2013 | ICA | CAAP-12-0000591 [ADA] | Ayad v. Ayad (Order Dismissing Appeal Pursuant to HRAP Rule 30). | Family Court, 2nd Circuit |
01/03/2013 | ICA | CAAP-12-0000576 [ADA] | Kunishige v. Eckerle (Order Dismissing Appeal for Lack of Jurisdiction). | Circuit Court, 3rd Circuit |
01/03/2013 | ICA | CAAP-12-0000540 [ADA] | Sing v. Mossman (Order Dismissing Appeal for Lack of Appellate Jurisdiction). | Circuit Court, 3rd Circuit |
01/03/2013 | S.Ct | SCPW-12-0000894 [ADA] | State v. Slavick (Order Denying Motion for Reconsideration). S.Ct. Order Denying without Prejudice Petition for Writ of Prohibition, filed 11/08/2012 [ada]. Motion for Reconsideration, filed 12/27/2012. | Circuit Court, 1st Circuit |
01/03/2013 | S.Ct | SCWC-11-0000625 [ADA] | Sierra Club v. Castle & Cooke Homes Hawaii, Inc. (Order Accepting Application for Writ of Certiorari). ICA Opinion, filed 08/24/2012 [ada], 128 Haw. 375. Consolidated with Nos. CAAP-11-0000627, CAAP-11-0000730 and CAAP-11-0000744. | Circuit Court, 1st Circuit |
01/02/2013 | ICA | CAAP-12-0000364 [ADA] | State, Department of Hawaiian Home Lands v. Kawa‘auhau (Order of Correction). ICA s.d.o., filed 11/29/2012 [ada], 128 Haw. 477. Motion for Reconsideration, filed 12/07/2012. ICA Order Denying Defendant-Appellant's Motion for Reconsideration, filed 12/13/2012 [ada]. | District Court, 1st Circuit |
01/02/2013 | S.Ct | SCPR-12-0001108 [ADA] | In re Murashige (Order Granting Petition to Resign and Surrender License). | Original Proceeding |
01/02/2013 | S.Ct | SCWC-11-0000802 [ADA] | State v. Casugay-Badiang (Order Accepting Application for Writ of Certiorari and Ordering Supplemental Briefing). ICA Opinion, filed 08/21/2012 [ada], 128 Haw. 370. Application for Writ of Certiorari, filed 11/16/2012. | Circuit Court, 1st Circuit |

© 2008 Hawaii State Judiciary. All rights reserved.

Privacy Policy | Terms of Use | Accessibility Information